// Copyright (C) 2007 CEREA
//
// CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
// (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
//
// This file is part of the air quality modeling system Polyphemus.
//
// Polyphemus is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// Polyphemus is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// For more information, please see the Polyphemus web site:
//     http://www.enpc.fr/cerea/polyphemus/


//////////////
// INCLUDES //

#define SELDONDATA_DEBUG_LEVEL_4
#define SELDONDATA_WITH_GRIB

#include "AtmoData.hxx"

#include "GradientDriver.cxx"
#include "Polair3DChemistryAssimConc.cxx"
#include "AdvectionDST3.cxx"
#include "DiffusionROS2.cxx"
#include "ChemistryRACM.cxx"
#include "BaseOutputSaver.cxx"
#include "GroundObservationManager.cxx"

using namespace Polyphemus;

// INCLUDES //
//////////////


int main(int argc, char** argv)
{

  TRY;

  if (argc != 2)
    {
      string mesg  = "Usage:\n";
      mesg += string("  ") + argv[0] + " [configuration file]";
      cout << mesg << endl;
      return 1;
    }

  typedef double real;
  typedef Polair3DChemistryAssimConc<real, AdvectionDST3<real>,
    DiffusionROS2<real>,
    ChemistryRACM<real> > ClassModel;

  GradientDriver<real, ClassModel,
    BaseOutputSaver<real, ClassModel>,
    GroundObservationManager<real> >
    Driver(argv[1]);

  Driver.Run();

  END;

  return 0;

}
