C-----------------------------------------------------------------------
C     Copyright (C) 2003-2007 CEREA
C     Author(s): SPACK
C
C     CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
C     (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
C
C     This file is part of the Regional Atmospheric Chemistry Modeling
C     (RACM), which is a component of the air quality modeling system
C     Polyphemus.
C
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C
C     For more information, please see the Polyphemus web site:
C            http://www.enpc.fr/cerea/polyphemus/
C-----------------------------------------------------------------------

      subroutine dratedc(NGAS,nr,rk,y,dw)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the derivative of reaction  rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: REACTIONS           
C     Species: _NAMSPECIES         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     RK: kinetic rates.
C     Y: chemical concentrations.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DW: derivative of reaction rates wrt Y.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
      
      INTEGER NGAS,nr
      
      double precision rk(nr),y(NGAS),dw(nr,NGAS)
      
      
      
      dw(  1, 80) =  rk(  1)
      dw(  2, 59) =  rk(  2)
      dw(  3, 59) =  rk(  3)
      dw(  4, 32) =  rk(  4)
      dw(  5, 67) =  rk(  5)
      dw(  6, 24) =  rk(  6)
      dw(  7, 77) =  rk(  7)
      dw(  8, 77) =  rk(  8)
      dw(  9, 45) =  rk(  9)
      dw( 10, 74) =  rk( 10)
      dw( 11, 74) =  rk( 11)
      dw( 12, 71) =  rk( 12)
      dw( 13, 25) =  rk( 13)
      dw( 14, 65) =  rk( 14)
      dw( 15, 35) =  rk( 15)
      dw( 16, 69) =  rk( 16)
      dw( 17, 61) =  rk( 17)
      dw( 18, 61) =  rk( 18)
      dw( 19, 66) =  rk( 19)
      dw( 20, 46) =  rk( 20)
      dw( 21, 82) =  rk( 21)
      dw( 22, 52) =  rk( 22)
      dw( 23, 41) =  rk( 23)
      dw( 24, 34) =  rk( 24)
      dw( 25, 34) =  rk( 25) * Y( 59)
      dw( 25, 59) =  rk( 25) * Y( 34)
      dw( 26,  7) =  rk( 26)
      dw( 27,  7) =  rk( 27)
      dw( 28,  7) =  rk( 28)
      dw( 29, 59) =  rk( 29) * Y( 75)
      dw( 29, 75) =  rk( 29) * Y( 59)
      dw( 30, 59) =  rk( 30) * Y( 81)
      dw( 30, 81) =  rk( 30) * Y( 59)
      dw( 31, 75) =  rk( 31) * Y( 81)
      dw( 31, 81) =  rk( 31) * Y( 75)
      dw( 32, 45) =  rk( 32) * Y( 75)
      dw( 32, 75) =  rk( 32) * Y( 45)
      dw( 33, 81) =  rk( 33) * Y( 81)
      dw( 33, 81) =  rk( 33) * Y( 81)
      dw( 34, 81) =  rk( 34) * Y( 81)
      dw( 34, 81) =  rk( 34) * Y( 81)
      dw( 35, 34) =  rk( 35) * Y( 78)
      dw( 35, 78) =  rk( 35) * Y( 34)
      dw( 36, 34) =  rk( 36) * Y( 80)
      dw( 36, 80) =  rk( 36) * Y( 34)
      dw( 37, 34) =  rk( 37) * Y( 80)
      dw( 37, 80) =  rk( 37) * Y( 34)
      dw( 38, 75) =  rk( 38) * Y( 78)
      dw( 38, 78) =  rk( 38) * Y( 75)
      dw( 39, 75) =  rk( 39) * Y( 80)
      dw( 39, 80) =  rk( 39) * Y( 75)
      dw( 40, 75) =  rk( 40) * Y( 77)
      dw( 40, 77) =  rk( 40) * Y( 75)
      dw( 41, 81) =  rk( 41) * Y( 78)
      dw( 41, 78) =  rk( 41) * Y( 81)
      dw( 42, 81) =  rk( 42) * Y( 80)
      dw( 42, 80) =  rk( 42) * Y( 81)
      dw( 43, 24) =  rk( 43)
      dw( 44, 81) =  rk( 44) * Y( 77)
      dw( 44, 77) =  rk( 44) * Y( 81)
      dw( 45, 75) =  rk( 45) * Y( 32)
      dw( 45, 32) =  rk( 45) * Y( 75)
      dw( 46, 75) =  rk( 46) * Y( 67)
      dw( 46, 67) =  rk( 46) * Y( 75)
      dw( 47, 75) =  rk( 47) * Y( 24)
      dw( 47, 24) =  rk( 47) * Y( 75)
      dw( 48, 59) =  rk( 48) * Y( 78)
      dw( 48, 78) =  rk( 48) * Y( 59)
      dw( 49, 59) =  rk( 49) * Y( 80)
      dw( 49, 80) =  rk( 49) * Y( 59)
      dw( 50, 78) =  rk( 50) * Y( 78)
      dw( 50, 78) =  rk( 50) * Y( 78)
      dw( 51, 77) =  rk( 51) * Y( 78)
      dw( 51, 78) =  rk( 51) * Y( 77)
      dw( 52, 77) =  rk( 52) * Y( 80)
      dw( 52, 80) =  rk( 52) * Y( 77)
      dw( 53, 77) =  rk( 53) * Y( 80)
      dw( 53, 80) =  rk( 53) * Y( 77)
      dw( 54, 13) =  rk( 54)
      dw( 55, 77) =  rk( 55) * Y( 77)
      dw( 55, 77) =  rk( 55) * Y( 77)
      dw( 56, 75) =  rk( 56)
      dw( 57, 75) =  rk( 57) * Y(  9)
      dw( 57,  9) =  rk( 57) * Y( 75)
      dw( 58, 60) =  rk( 58) * Y( 75)
      dw( 58, 75) =  rk( 58) * Y( 60)
      dw( 59, 28) =  rk( 59) * Y( 34)
      dw( 59, 34) =  rk( 59) * Y( 28)
      dw( 60, 52) =  rk( 60) * Y( 34)
      dw( 60, 34) =  rk( 60) * Y( 52)
      dw( 61, 29) =  rk( 61) * Y( 75)
      dw( 61, 75) =  rk( 61) * Y( 29)
      dw( 62, 30) =  rk( 62) * Y( 75)
      dw( 62, 75) =  rk( 62) * Y( 30)
      dw( 63, 11) =  rk( 63) * Y( 75)
      dw( 63, 75) =  rk( 63) * Y( 11)
      dw( 64,  3) =  rk( 64) * Y( 75)
      dw( 64, 75) =  rk( 64) * Y(  3)
      dw( 65,  4) =  rk( 65) * Y( 75)
      dw( 65, 75) =  rk( 65) * Y(  4)
      dw( 66, 27) =  rk( 66) * Y( 75)
      dw( 66, 75) =  rk( 66) * Y( 27)
      dw( 67, 53) =  rk( 67) * Y( 75)
      dw( 67, 75) =  rk( 67) * Y( 53)
      dw( 68, 56) =  rk( 68) * Y( 75)
      dw( 68, 75) =  rk( 68) * Y( 56)
      dw( 69, 21) =  rk( 69) * Y( 75)
      dw( 69, 75) =  rk( 69) * Y( 21)
      dw( 70, 28) =  rk( 70) * Y( 75)
      dw( 70, 75) =  rk( 70) * Y( 28)
      dw( 71, 26) =  rk( 71) * Y( 75)
      dw( 71, 75) =  rk( 71) * Y( 26)
      dw( 72, 14) =  rk( 72) * Y( 75)
      dw( 72, 75) =  rk( 72) * Y( 14)
      dw( 73,  5) =  rk( 73) * Y( 75)
      dw( 73, 75) =  rk( 73) * Y(  5)
      dw( 74,  6) =  rk( 74) * Y( 75)
      dw( 74, 75) =  rk( 74) * Y(  6)
      dw( 75, 37) =  rk( 75) * Y( 75)
      dw( 75, 75) =  rk( 75) * Y( 37)
      dw( 76, 74) =  rk( 76) * Y( 75)
      dw( 76, 75) =  rk( 76) * Y( 74)
      dw( 77, 71) =  rk( 77) * Y( 75)
      dw( 77, 75) =  rk( 77) * Y( 71)
      dw( 78, 69) =  rk( 78) * Y( 75)
      dw( 78, 75) =  rk( 78) * Y( 69)
      dw( 79, 41) =  rk( 79) * Y( 75)
      dw( 79, 75) =  rk( 79) * Y( 41)
      dw( 80, 61) =  rk( 80) * Y( 75)
      dw( 80, 75) =  rk( 80) * Y( 61)
      dw( 81, 66) =  rk( 81) * Y( 75)
      dw( 81, 75) =  rk( 81) * Y( 66)
      dw( 82, 52) =  rk( 82) * Y( 75)
      dw( 82, 75) =  rk( 82) * Y( 52)
      dw( 83, 75) =  rk( 83) * Y( 46)
      dw( 83, 46) =  rk( 83) * Y( 75)
      dw( 84, 75) =  rk( 84) * Y( 12)
      dw( 84, 12) =  rk( 84) * Y( 75)
      dw( 85, 25) =  rk( 85) * Y( 75)
      dw( 85, 75) =  rk( 85) * Y( 25)
      dw( 86, 65) =  rk( 86) * Y( 75)
      dw( 86, 75) =  rk( 86) * Y( 65)
      dw( 87, 35) =  rk( 87) * Y( 75)
      dw( 87, 75) =  rk( 87) * Y( 35)
      dw( 88, 44) =  rk( 88) * Y( 75)
      dw( 88, 75) =  rk( 88) * Y( 44)
      dw( 89, 42) =  rk( 89) * Y( 75)
      dw( 89, 75) =  rk( 89) * Y( 42)
      dw( 90, 82) =  rk( 90) * Y( 75)
      dw( 90, 75) =  rk( 90) * Y( 82)
      dw( 91, 74) =  rk( 91) * Y( 77)
      dw( 91, 77) =  rk( 91) * Y( 74)
      dw( 92, 71) =  rk( 92) * Y( 77)
      dw( 92, 77) =  rk( 92) * Y( 71)
      dw( 93, 61) =  rk( 93) * Y( 77)
      dw( 93, 77) =  rk( 93) * Y( 61)
      dw( 94, 66) =  rk( 94) * Y( 77)
      dw( 94, 77) =  rk( 94) * Y( 66)
      dw( 95, 52) =  rk( 95) * Y( 77)
      dw( 95, 77) =  rk( 95) * Y( 52)
      dw( 96, 46) =  rk( 96) * Y( 77)
      dw( 96, 77) =  rk( 96) * Y( 46)
      dw( 97, 37) =  rk( 97) * Y( 77)
      dw( 97, 77) =  rk( 97) * Y( 37)
      dw( 98, 27) =  rk( 98) * Y( 77)
      dw( 98, 77) =  rk( 98) * Y( 27)
      dw( 99, 53) =  rk( 99) * Y( 77)
      dw( 99, 77) =  rk( 99) * Y( 53)
      dw(100, 56) =  rk(100) * Y( 77)
      dw(100, 77) =  rk(100) * Y( 56)
      dw(101, 21) =  rk(101) * Y( 77)
      dw(101, 77) =  rk(101) * Y( 21)
      dw(102, 28) =  rk(102) * Y( 77)
      dw(102, 77) =  rk(102) * Y( 28)
      dw(103, 26) =  rk(103) * Y( 77)
      dw(103, 77) =  rk(103) * Y( 26)
      dw(104, 14) =  rk(104) * Y( 77)
      dw(104, 77) =  rk(104) * Y( 14)
      dw(105, 42) =  rk(105) * Y( 77)
      dw(105, 77) =  rk(105) * Y( 42)
      dw(106, 27) =  rk(106) * Y( 59)
      dw(106, 59) =  rk(106) * Y( 27)
      dw(107, 53) =  rk(107) * Y( 59)
      dw(107, 59) =  rk(107) * Y( 53)
      dw(108, 56) =  rk(108) * Y( 59)
      dw(108, 59) =  rk(108) * Y( 56)
      dw(109, 21) =  rk(109) * Y( 59)
      dw(109, 59) =  rk(109) * Y( 21)
      dw(110, 28) =  rk(110) * Y( 59)
      dw(110, 59) =  rk(110) * Y( 28)
      dw(111, 26) =  rk(111) * Y( 59)
      dw(111, 59) =  rk(111) * Y( 26)
      dw(112, 14) =  rk(112) * Y( 59)
      dw(112, 59) =  rk(112) * Y( 14)
      dw(113, 52) =  rk(113) * Y( 59)
      dw(113, 59) =  rk(113) * Y( 52)
      dw(114, 46) =  rk(114) * Y( 59)
      dw(114, 59) =  rk(114) * Y( 46)
      dw(115, 42) =  rk(115) * Y( 59)
      dw(115, 59) =  rk(115) * Y( 42)
      dw(116, 36) =  rk(116) * Y( 80)
      dw(116, 80) =  rk(116) * Y( 36)
      dw(117, 36) =  rk(117) * Y( 81)
      dw(117, 81) =  rk(117) * Y( 36)
      dw(118, 17) =  rk(118) * Y( 80)
      dw(118, 80) =  rk(118) * Y( 17)
      dw(119, 17) =  rk(119)
      dw(120, 17) =  rk(120) * Y( 59)
      dw(120, 59) =  rk(120) * Y( 17)
      dw(121, 18) =  rk(121) * Y( 80)
      dw(121, 80) =  rk(121) * Y( 18)
      dw(122, 18) =  rk(122)
      dw(123, 18) =  rk(123) * Y( 59)
      dw(123, 59) =  rk(123) * Y( 18)
      dw(124, 31) =  rk(124) * Y( 80)
      dw(124, 80) =  rk(124) * Y( 31)
      dw(125, 31) =  rk(125)
      dw(126, 31) =  rk(126) * Y( 59)
      dw(126, 59) =  rk(126) * Y( 31)
      dw(127, 76) =  rk(127) * Y( 80)
      dw(127, 80) =  rk(127) * Y( 76)
      dw(128, 44) =  rk(128)
      dw(129, 79) =  rk(129) * Y( 80)
      dw(129, 80) =  rk(129) * Y( 79)
      dw(130, 42) =  rk(130)
      dw(131, 73) =  rk(131) * Y( 78)
      dw(131, 78) =  rk(131) * Y( 73)
      dw(132, 70) =  rk(132) * Y( 78)
      dw(132, 78) =  rk(132) * Y( 70)
      dw(133, 68) =  rk(133) * Y( 78)
      dw(133, 78) =  rk(133) * Y( 68)
      dw(134, 48) =  rk(134) * Y( 78)
      dw(134, 78) =  rk(134) * Y( 48)
      dw(135, 49) =  rk(135) * Y( 78)
      dw(135, 78) =  rk(135) * Y( 49)
      dw(136, 50) =  rk(136) * Y( 78)
      dw(136, 78) =  rk(136) * Y( 50)
      dw(137, 54) =  rk(137) * Y( 78)
      dw(137, 78) =  rk(137) * Y( 54)
      dw(138, 62) =  rk(138) * Y( 78)
      dw(138, 78) =  rk(138) * Y( 62)
      dw(139, 51) =  rk(139) * Y( 78)
      dw(139, 78) =  rk(139) * Y( 51)
      dw(140, 55) =  rk(140) * Y( 78)
      dw(140, 78) =  rk(140) * Y( 55)
      dw(141, 47) =  rk(141) * Y( 78)
      dw(141, 78) =  rk(141) * Y( 47)
      dw(142, 39) =  rk(142) * Y( 78)
      dw(142, 78) =  rk(142) * Y( 39)
      dw(143, 40) =  rk(143) * Y( 78)
      dw(143, 78) =  rk(143) * Y( 40)
      dw(144, 33) =  rk(144) * Y( 78)
      dw(144, 78) =  rk(144) * Y( 33)
      dw(145, 76) =  rk(145) * Y( 78)
      dw(145, 78) =  rk(145) * Y( 76)
      dw(146, 79) =  rk(146) * Y( 78)
      dw(146, 78) =  rk(146) * Y( 79)
      dw(147, 64) =  rk(147) * Y( 78)
      dw(147, 78) =  rk(147) * Y( 64)
      dw(148, 57) =  rk(148) * Y( 78)
      dw(148, 78) =  rk(148) * Y( 57)
      dw(149, 58) =  rk(149) * Y( 78)
      dw(149, 78) =  rk(149) * Y( 58)
      dw(150, 73) =  rk(150) * Y( 81)
      dw(150, 81) =  rk(150) * Y( 73)
      dw(151, 70) =  rk(151) * Y( 81)
      dw(151, 81) =  rk(151) * Y( 70)
      dw(152, 68) =  rk(152) * Y( 81)
      dw(152, 81) =  rk(152) * Y( 68)
      dw(153, 48) =  rk(153) * Y( 81)
      dw(153, 81) =  rk(153) * Y( 48)
      dw(154, 49) =  rk(154) * Y( 81)
      dw(154, 81) =  rk(154) * Y( 49)
      dw(155, 50) =  rk(155) * Y( 81)
      dw(155, 81) =  rk(155) * Y( 50)
      dw(156, 54) =  rk(156) * Y( 81)
      dw(156, 81) =  rk(156) * Y( 54)
      dw(157, 62) =  rk(157) * Y( 81)
      dw(157, 81) =  rk(157) * Y( 62)
      dw(158, 51) =  rk(158) * Y( 81)
      dw(158, 81) =  rk(158) * Y( 51)
      dw(159, 55) =  rk(159) * Y( 81)
      dw(159, 81) =  rk(159) * Y( 55)
      dw(160, 47) =  rk(160) * Y( 81)
      dw(160, 81) =  rk(160) * Y( 47)
      dw(161, 39) =  rk(161) * Y( 81)
      dw(161, 81) =  rk(161) * Y( 39)
      dw(162, 40) =  rk(162) * Y( 81)
      dw(162, 81) =  rk(162) * Y( 40)
      dw(163, 33) =  rk(163) * Y( 81)
      dw(163, 81) =  rk(163) * Y( 33)
      dw(164, 76) =  rk(164) * Y( 81)
      dw(164, 81) =  rk(164) * Y( 76)
      dw(165, 76) =  rk(165) * Y( 81)
      dw(165, 81) =  rk(165) * Y( 76)
      dw(166, 79) =  rk(166) * Y( 81)
      dw(166, 81) =  rk(166) * Y( 79)
      dw(167, 79) =  rk(167) * Y( 81)
      dw(167, 81) =  rk(167) * Y( 79)
      dw(168, 64) =  rk(168) * Y( 81)
      dw(168, 81) =  rk(168) * Y( 64)
      dw(169, 57) =  rk(169) * Y( 81)
      dw(169, 81) =  rk(169) * Y( 57)
      dw(170, 58) =  rk(170) * Y( 81)
      dw(170, 81) =  rk(170) * Y( 58)
      dw(171, 73) =  rk(171) * Y( 73)
      dw(171, 73) =  rk(171) * Y( 73)
      dw(172, 70) =  rk(172) * Y( 73)
      dw(172, 73) =  rk(172) * Y( 70)
      dw(173, 68) =  rk(173) * Y( 73)
      dw(173, 73) =  rk(173) * Y( 68)
      dw(174, 48) =  rk(174) * Y( 73)
      dw(174, 73) =  rk(174) * Y( 48)
      dw(175, 49) =  rk(175) * Y( 73)
      dw(175, 73) =  rk(175) * Y( 49)
      dw(176, 50) =  rk(176) * Y( 73)
      dw(176, 73) =  rk(176) * Y( 50)
      dw(177, 54) =  rk(177) * Y( 73)
      dw(177, 73) =  rk(177) * Y( 54)
      dw(178, 62) =  rk(178) * Y( 73)
      dw(178, 73) =  rk(178) * Y( 62)
      dw(179, 51) =  rk(179) * Y( 73)
      dw(179, 73) =  rk(179) * Y( 51)
      dw(180, 55) =  rk(180) * Y( 73)
      dw(180, 73) =  rk(180) * Y( 55)
      dw(181, 47) =  rk(181) * Y( 73)
      dw(181, 73) =  rk(181) * Y( 47)
      dw(182, 39) =  rk(182) * Y( 73)
      dw(182, 73) =  rk(182) * Y( 39)
      dw(183, 40) =  rk(183) * Y( 73)
      dw(183, 73) =  rk(183) * Y( 40)
      dw(184, 33) =  rk(184) * Y( 73)
      dw(184, 73) =  rk(184) * Y( 33)
      dw(185, 76) =  rk(185) * Y( 73)
      dw(185, 73) =  rk(185) * Y( 76)
      dw(186, 76) =  rk(186) * Y( 73)
      dw(186, 73) =  rk(186) * Y( 76)
      dw(187, 79) =  rk(187) * Y( 73)
      dw(187, 73) =  rk(187) * Y( 79)
      dw(188, 79) =  rk(188) * Y( 73)
      dw(188, 73) =  rk(188) * Y( 79)
      dw(189, 64) =  rk(189) * Y( 73)
      dw(189, 73) =  rk(189) * Y( 64)
      dw(190, 57) =  rk(190) * Y( 73)
      dw(190, 73) =  rk(190) * Y( 57)
      dw(191, 58) =  rk(191) * Y( 73)
      dw(191, 73) =  rk(191) * Y( 58)
      dw(192, 70) =  rk(192) * Y( 76)
      dw(192, 76) =  rk(192) * Y( 70)
      dw(193, 68) =  rk(193) * Y( 76)
      dw(193, 76) =  rk(193) * Y( 68)
      dw(194, 48) =  rk(194) * Y( 76)
      dw(194, 76) =  rk(194) * Y( 48)
      dw(195, 49) =  rk(195) * Y( 76)
      dw(195, 76) =  rk(195) * Y( 49)
      dw(196, 50) =  rk(196) * Y( 76)
      dw(196, 76) =  rk(196) * Y( 50)
      dw(197, 54) =  rk(197) * Y( 76)
      dw(197, 76) =  rk(197) * Y( 54)
      dw(198, 62) =  rk(198) * Y( 76)
      dw(198, 76) =  rk(198) * Y( 62)
      dw(199, 51) =  rk(199) * Y( 76)
      dw(199, 76) =  rk(199) * Y( 51)
      dw(200, 55) =  rk(200) * Y( 76)
      dw(200, 76) =  rk(200) * Y( 55)
      dw(201, 47) =  rk(201) * Y( 76)
      dw(201, 76) =  rk(201) * Y( 47)
      dw(202, 39) =  rk(202) * Y( 76)
      dw(202, 76) =  rk(202) * Y( 39)
      dw(203, 40) =  rk(203) * Y( 76)
      dw(203, 76) =  rk(203) * Y( 40)
      dw(204, 33) =  rk(204) * Y( 76)
      dw(204, 76) =  rk(204) * Y( 33)
      dw(205, 76) =  rk(205) * Y( 76)
      dw(205, 76) =  rk(205) * Y( 76)
      dw(206, 79) =  rk(206) * Y( 76)
      dw(206, 76) =  rk(206) * Y( 79)
      dw(207, 64) =  rk(207) * Y( 76)
      dw(207, 76) =  rk(207) * Y( 64)
      dw(208, 57) =  rk(208) * Y( 76)
      dw(208, 76) =  rk(208) * Y( 57)
      dw(209, 58) =  rk(209) * Y( 76)
      dw(209, 76) =  rk(209) * Y( 58)
      dw(210, 57) =  rk(210) * Y( 57)
      dw(210, 57) =  rk(210) * Y( 57)
      dw(211, 57) =  rk(211) * Y( 58)
      dw(211, 58) =  rk(211) * Y( 57)
      dw(212, 58) =  rk(212) * Y( 58)
      dw(212, 58) =  rk(212) * Y( 58)
      dw(213, 73) =  rk(213) * Y( 77)
      dw(213, 77) =  rk(213) * Y( 73)
      dw(214, 70) =  rk(214) * Y( 77)
      dw(214, 77) =  rk(214) * Y( 70)
      dw(215, 68) =  rk(215) * Y( 77)
      dw(215, 77) =  rk(215) * Y( 68)
      dw(216, 48) =  rk(216) * Y( 77)
      dw(216, 77) =  rk(216) * Y( 48)
      dw(217, 49) =  rk(217) * Y( 77)
      dw(217, 77) =  rk(217) * Y( 49)
      dw(218, 50) =  rk(218) * Y( 77)
      dw(218, 77) =  rk(218) * Y( 50)
      dw(219, 54) =  rk(219) * Y( 77)
      dw(219, 77) =  rk(219) * Y( 54)
      dw(220, 62) =  rk(220) * Y( 77)
      dw(220, 77) =  rk(220) * Y( 62)
      dw(221, 51) =  rk(221) * Y( 77)
      dw(221, 77) =  rk(221) * Y( 51)
      dw(222, 55) =  rk(222) * Y( 77)
      dw(222, 77) =  rk(222) * Y( 55)
      dw(223, 47) =  rk(223) * Y( 77)
      dw(223, 77) =  rk(223) * Y( 47)
      dw(224, 39) =  rk(224) * Y( 77)
      dw(224, 77) =  rk(224) * Y( 39)
      dw(225, 40) =  rk(225) * Y( 77)
      dw(225, 77) =  rk(225) * Y( 40)
      dw(226, 33) =  rk(226) * Y( 77)
      dw(226, 77) =  rk(226) * Y( 33)
      dw(227, 76) =  rk(227) * Y( 77)
      dw(227, 77) =  rk(227) * Y( 76)
      dw(228, 79) =  rk(228) * Y( 77)
      dw(228, 77) =  rk(228) * Y( 79)
      dw(229, 64) =  rk(229) * Y( 77)
      dw(229, 77) =  rk(229) * Y( 64)
      dw(230, 57) =  rk(230) * Y( 77)
      dw(230, 77) =  rk(230) * Y( 57)
      dw(231, 58) =  rk(231) * Y( 77)
      dw(231, 77) =  rk(231) * Y( 58)
      dw(232, 72) =  rk(232) * Y( 81)
      dw(232, 81) =  rk(232) * Y( 72)
      dw(233, 72) =  rk(233) * Y( 73)
      dw(233, 73) =  rk(233) * Y( 72)
      dw(234, 72) =  rk(234) * Y( 76)
      dw(234, 76) =  rk(234) * Y( 72)
      dw(235, 72) =  rk(235) * Y( 72)
      dw(235, 72) =  rk(235) * Y( 72)
      dw(236, 72) =  rk(236) * Y( 78)
      dw(236, 78) =  rk(236) * Y( 72)
      dw(237, 72) =  rk(237) * Y( 77)
      dw(237, 77) =  rk(237) * Y( 72)
      dw(238, 81) =  rk(238)
      dw(239, 80) =  rk(239)
      dw(240, 77) =  rk(240)
      dw(241, 13) =  rk(241)
      RETURN
      END
      
