C-----------------------------------------------------------------------
C     Copyright (C) 2003-2007 CEREA
C     Author(s): SPACK
C
C     CEREA (http://www.enpc.fr/cerea/) is a joint laboratory of ENPC
C     (http://www.enpc.fr/) and EDF R&D (http://www.edf.fr/).
C
C     This file is part of the Regional Atmospheric Chemistry Modeling
C     (RACM), which is a component of the air quality modeling system
C     Polyphemus.
C
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C
C     For more information, please see the Polyphemus web site:
C            http://www.enpc.fr/cerea/polyphemus/
C-----------------------------------------------------------------------

      subroutine fexchem(NESP,Nr,nemis,y,rk,ZCsourc,chem)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: REACTIONS           
C     Species: _NAMSPECIES         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CHEM: array of chemical production terms.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
      
      INTEGER NESP,Nr,nemis
      double precision w(Nr),rk(Nr),y(NESP),chem(NESP),ZCsourc(NESP)
      integer i
      
      do i=1,NESP
         chem(i)=0.d0
      enddo
      
C     Compute reaction rates.
      
      call rates(NESP,nr,rk,y,w)
      
C     Chemical production terms.
      
      chem( 34) = chem( 34) + w(  1)
      chem( 78) = chem( 78) + w(  1)
      chem( 80) = chem( 80) - w(  1)
      chem(  7) = chem(  7) + w(  2)
      chem( 59) = chem( 59) - w(  2)
      chem( 34) = chem( 34) + w(  3)
      chem( 59) = chem( 59) - w(  3)
      chem( 32) = chem( 32) - w(  4)
      chem( 75) = chem( 75) + w(  4)
      chem( 78) = chem( 78) + w(  4)
      chem( 67) = chem( 67) - w(  5)
      chem( 75) = chem( 75) + w(  5)
      chem( 80) = chem( 80) + w(  5)
      chem( 24) = chem( 24) - w(  6)
      chem( 75) = chem( 75) +  0.3500000000000000D+00 * w(  6)
      chem( 77) = chem( 77) +  0.3500000000000000D+00 * w(  6)
      chem( 80) = chem( 80) +  0.6500000000000000D+00 * w(  6)
      chem( 81) = chem( 81) +  0.6500000000000000D+00 * w(  6)
      chem( 77) = chem( 77) - w(  7)
      chem( 78) = chem( 78) + w(  7)
      chem( 34) = chem( 34) + w(  8)
      chem( 77) = chem( 77) - w(  8)
      chem( 80) = chem( 80) + w(  8)
      chem( 45) = chem( 45) - w(  9)
      chem( 75) = chem( 75) +  0.2000000000000000D+01 * w(  9)
      chem( 60) = chem( 60) + w( 10)
      chem( 74) = chem( 74) - w( 10)
      chem( 60) = chem( 60) + w( 11)
      chem( 74) = chem( 74) - w( 11)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w( 11)
      chem( 60) = chem( 60) + w( 12)
      chem( 71) = chem( 71) - w( 12)
      chem( 73) = chem( 73) + w( 12)
      chem( 81) = chem( 81) + w( 12)
      chem( 25) = chem( 25) - w( 13)
      chem( 74) = chem( 74) + w( 13)
      chem( 75) = chem( 75) + w( 13)
      chem( 81) = chem( 81) + w( 13)
      chem( 65) = chem( 65) - w( 14)
      chem( 71) = chem( 71) + w( 14)
      chem( 75) = chem( 75) + w( 14)
      chem( 81) = chem( 81) + w( 14)
      chem( 35) = chem( 35) - w( 15)
      chem( 73) = chem( 73) + w( 15)
      chem( 75) = chem( 75) + w( 15)
      chem( 69) = chem( 69) - w( 16)
      chem( 70) = chem( 70) + w( 16)
      chem( 76) = chem( 76) + w( 16)
      chem( 60) = chem( 60) +  0.1870000000000000D+01 * w( 17)
      chem( 61) = chem( 61) - w( 17)
      chem( 74) = chem( 74) +  0.1300000000000000D+00 * w( 17)
      chem( 60) = chem( 60) +  0.1550000000000000D+01 * w( 18)
      chem( 61) = chem( 61) - w( 18)
      chem( 74) = chem( 74) +  0.4500000000000000D+00 * w( 18)
      chem( 81) = chem( 81) +  0.8000000000000000D+00 * w( 18)
      chem( 60) = chem( 60) + w( 19)
      chem( 66) = chem( 66) - w( 19)
      chem( 76) = chem( 76) + w( 19)
      chem( 81) = chem( 81) + w( 19)
      chem( 46) = chem( 46) - w( 20)
      chem( 79) = chem( 79) + w( 20)
      chem( 81) = chem( 81) + w( 20)
      chem( 69) = chem( 69) +  0.8000000000000000D+00 * w( 21)
      chem( 71) = chem( 71) +  0.2000000000000000D+00 * w( 21)
      chem( 80) = chem( 80) + w( 21)
      chem( 81) = chem( 81) + w( 21)
      chem( 82) = chem( 82) - w( 21)
      chem( 52) = chem( 52) - w( 22)
      chem( 60) = chem( 60) + w( 22)
      chem( 74) = chem( 74) + w( 22)
      chem( 76) = chem( 76) + w( 22)
      chem( 81) = chem( 81) + w( 22)
      chem( 41) = chem( 41) - w( 23)
      chem( 74) = chem( 74) + w( 23)
      chem( 76) = chem( 76) + w( 23)
      chem( 81) = chem( 81) + w( 23)
      chem( 34) = chem( 34) - w( 24)
      chem( 59) = chem( 59) + w( 24)
      chem( 34) = chem( 34) - w( 25)
      chem( 59) = chem( 59) - w( 25)
      chem(  7) = chem(  7) - w( 26)
      chem( 34) = chem( 34) + w( 26)
      chem(  7) = chem(  7) - w( 27)
      chem( 34) = chem( 34) + w( 27)
      chem(  7) = chem(  7) - w( 28)
      chem( 75) = chem( 75) +  0.2000000000000000D+01 * w( 28)
      chem( 59) = chem( 59) - w( 29)
      chem( 75) = chem( 75) - w( 29)
      chem( 81) = chem( 81) + w( 29)
      chem( 59) = chem( 59) - w( 30)
      chem( 75) = chem( 75) + w( 30)
      chem( 81) = chem( 81) - w( 30)
      chem( 75) = chem( 75) - w( 31)
      chem( 81) = chem( 81) - w( 31)
      chem( 45) = chem( 45) - w( 32)
      chem( 75) = chem( 75) - w( 32)
      chem( 81) = chem( 81) + w( 32)
      chem( 45) = chem( 45) + w( 33)
      chem( 81) = chem( 81) -  0.2000000000000000D+01 * w( 33)
      chem( 45) = chem( 45) + w( 34)
      chem( 81) = chem( 81) -  0.2000000000000000D+01 * w( 34)
      chem( 34) = chem( 34) - w( 35)
      chem( 78) = chem( 78) - w( 35)
      chem( 80) = chem( 80) + w( 35)
      chem( 34) = chem( 34) - w( 36)
      chem( 78) = chem( 78) + w( 36)
      chem( 80) = chem( 80) - w( 36)
      chem( 34) = chem( 34) - w( 37)
      chem( 77) = chem( 77) + w( 37)
      chem( 80) = chem( 80) - w( 37)
      chem( 32) = chem( 32) + w( 38)
      chem( 75) = chem( 75) - w( 38)
      chem( 78) = chem( 78) - w( 38)
      chem( 67) = chem( 67) + w( 39)
      chem( 75) = chem( 75) - w( 39)
      chem( 80) = chem( 80) - w( 39)
      chem( 75) = chem( 75) - w( 40)
      chem( 77) = chem( 77) - w( 40)
      chem( 80) = chem( 80) + w( 40)
      chem( 81) = chem( 81) + w( 40)
      chem( 75) = chem( 75) + w( 41)
      chem( 78) = chem( 78) - w( 41)
      chem( 80) = chem( 80) + w( 41)
      chem( 81) = chem( 81) - w( 41)
      chem( 24) = chem( 24) + w( 42)
      chem( 80) = chem( 80) - w( 42)
      chem( 81) = chem( 81) - w( 42)
      chem( 24) = chem( 24) - w( 43)
      chem( 80) = chem( 80) + w( 43)
      chem( 81) = chem( 81) + w( 43)
      chem( 67) = chem( 67) +  0.3000000000000000D+00 * w( 44)
      chem( 75) = chem( 75) +  0.7000000000000000D+00 * w( 44)
      chem( 77) = chem( 77) - w( 44)
      chem( 80) = chem( 80) +  0.7000000000000000D+00 * w( 44)
      chem( 81) = chem( 81) - w( 44)
      chem( 32) = chem( 32) - w( 45)
      chem( 75) = chem( 75) - w( 45)
      chem( 80) = chem( 80) + w( 45)
      chem( 67) = chem( 67) - w( 46)
      chem( 75) = chem( 75) - w( 46)
      chem( 77) = chem( 77) + w( 46)
      chem( 24) = chem( 24) - w( 47)
      chem( 75) = chem( 75) - w( 47)
      chem( 80) = chem( 80) + w( 47)
      chem( 59) = chem( 59) - w( 48)
      chem( 78) = chem( 78) - w( 48)
      chem( 80) = chem( 80) + w( 48)
      chem( 59) = chem( 59) - w( 49)
      chem( 77) = chem( 77) + w( 49)
      chem( 80) = chem( 80) - w( 49)
      chem( 78) = chem( 78) -  0.2000000000000000D+01 * w( 50)
      chem( 80) = chem( 80) +  0.2000000000000000D+01 * w( 50)
      chem( 77) = chem( 77) - w( 51)
      chem( 78) = chem( 78) - w( 51)
      chem( 80) = chem( 80) +  0.2000000000000000D+01 * w( 51)
      chem( 77) = chem( 77) - w( 52)
      chem( 78) = chem( 78) + w( 52)
      chem( 13) = chem( 13) + w( 53)
      chem( 77) = chem( 77) - w( 53)
      chem( 80) = chem( 80) - w( 53)
      chem( 13) = chem( 13) - w( 54)
      chem( 77) = chem( 77) + w( 54)
      chem( 80) = chem( 80) + w( 54)
      chem( 77) = chem( 77) -  0.2000000000000000D+01 * w( 55)
      chem( 80) = chem( 80) +  0.2000000000000000D+01 * w( 55)
      chem( 75) = chem( 75) - w( 56)
      chem( 81) = chem( 81) + w( 56)
      chem(  9) = chem(  9) - w( 57)
      chem( 10) = chem( 10) + w( 57)
      chem( 75) = chem( 75) - w( 57)
      chem( 81) = chem( 81) + w( 57)
      chem( 60) = chem( 60) - w( 58)
      chem( 75) = chem( 75) - w( 58)
      chem( 81) = chem( 81) + w( 58)
      chem( 28) = chem( 28) - w( 59)
      chem( 34) = chem( 34) - w( 59)
      chem( 46) = chem( 46) +  0.1300000000000000D+00 * w( 59)
      chem( 53) = chem( 53) +  0.8600000000000000D+00 * w( 59)
      chem( 60) = chem( 60) +  0.1000000000000000D-01 * w( 59)
      chem( 72) = chem( 72) +  0.1500000000000000D+00 * w( 59)
      chem( 74) = chem( 74) +  0.5000000000000000D-01 * w( 59)
      chem( 75) = chem( 75) +  0.2000000000000000D-01 * w( 59)
      chem( 81) = chem( 81) +  0.2800000000000000D+00 * w( 59)
      chem( 34) = chem( 34) - w( 60)
      chem( 52) = chem( 52) - w( 60)
      chem( 71) = chem( 71) + w( 60)
      chem( 29) = chem( 29) - w( 61)
      chem( 73) = chem( 73) + w( 61)
      chem( 75) = chem( 75) - w( 61)
      chem( 30) = chem( 30) - w( 62)
      chem( 70) = chem( 70) + w( 62)
      chem( 75) = chem( 75) - w( 62)
      chem( 11) = chem( 11) - w( 63)
      chem( 43) = chem( 43) +  0.3600000000000000D-01 * w( 63)
      chem( 60) = chem( 60) +  0.3600000000000000D-01 * w( 63)
      chem( 61) = chem( 61) +  0.3600000000000000D-01 * w( 63)
      chem( 68) = chem( 68) +  0.5830000000000000D+00 * w( 63)
      chem( 71) = chem( 71) +  0.3350000000000000D+00 * w( 63)
      chem( 74) = chem( 74) +  0.1000000000000000D-01 * w( 63)
      chem( 75) = chem( 75) -  0.9640000000000000D+00 * w( 63)
      chem( 81) = chem( 81) +  0.3810000000000000D+00 * w( 63)
      chem(  3) = chem(  3) - w( 64)
      chem( 48) = chem( 48) +  0.7500000000000000D+00 * w( 64)
      chem( 69) = chem( 69) +  0.2500000000000000D+00 * w( 64)
      chem( 75) = chem( 75) - w( 64)
      chem( 81) = chem( 81) +  0.2500000000000000D+00 * w( 64)
      chem(  4) = chem(  4) - w( 65)
      chem(  8) = chem(  8) +  0.4800000000000000D-01 * w( 65)
      chem( 41) = chem( 41) +  0.2400000000000000D-01 * w( 65)
      chem( 49) = chem( 49) +  0.9510000000000000D+00 * w( 65)
      chem( 71) = chem( 71) +  0.2500000000000000D-01 * w( 65)
      chem( 75) = chem( 75) - w( 65)
      chem( 81) = chem( 81) +  0.4900000000000000D-01 * w( 65)
      chem( 27) = chem( 27) - w( 66)
      chem( 50) = chem( 50) + w( 66)
      chem( 75) = chem( 75) - w( 66)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w( 67)
      chem( 53) = chem( 53) - w( 67)
      chem( 54) = chem( 54) + w( 67)
      chem( 75) = chem( 75) - w( 67)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w( 68)
      chem( 56) = chem( 56) - w( 68)
      chem( 62) = chem( 62) + w( 68)
      chem( 75) = chem( 75) - w( 68)
      chem( 21) = chem( 21) - w( 69)
      chem( 51) = chem( 51) + w( 69)
      chem( 75) = chem( 75) - w( 69)
      chem( 28) = chem( 28) - w( 70)
      chem( 51) = chem( 51) + w( 70)
      chem( 75) = chem( 75) - w( 70)
      chem( 22) = chem( 22) +  0.6384000000000000D-02 * w( 71)
      chem( 23) = chem( 23) +  0.5494800000000000D-01 * w( 71)
      chem( 26) = chem( 26) - w( 71)
      chem( 55) = chem( 55) + w( 71)
      chem( 75) = chem( 75) - w( 71)
      chem( 14) = chem( 14) - w( 72)
      chem( 15) = chem( 15) +  0.3716400000000000D-01 * w( 72)
      chem( 16) = chem( 16) +  0.5631600000000000D-01 * w( 72)
      chem( 47) = chem( 47) + w( 72)
      chem( 75) = chem( 75) - w( 72)
      chem(  5) = chem(  5) - w( 73)
      chem( 17) = chem( 17) +  0.9000000000000000D+00 * w( 73)
      chem( 19) = chem( 19) +  0.3900000000000000D-01 * w( 73)
      chem( 20) = chem( 20) +  0.1080000000000000D+00 * w( 73)
      chem( 72) = chem( 72) +  0.1000000000000000D+00 * w( 73)
      chem( 75) = chem( 75) - w( 73)
      chem( 81) = chem( 81) +  0.1000000000000000D+00 * w( 73)
      chem(  6) = chem(  6) - w( 74)
      chem( 18) = chem( 18) +  0.9000000000000000D+00 * w( 74)
      chem( 19) = chem( 19) +  0.3900000000000000D-01 * w( 74)
      chem( 20) = chem( 20) +  0.1080000000000000D+00 * w( 74)
      chem( 72) = chem( 72) +  0.1000000000000000D+00 * w( 74)
      chem( 75) = chem( 75) - w( 74)
      chem( 81) = chem( 81) +  0.1000000000000000D+00 * w( 74)
      chem( 19) = chem( 19) +  0.3900000000000000D-01 * w( 75)
      chem( 20) = chem( 20) +  0.1080000000000000D+00 * w( 75)
      chem( 31) = chem( 31) +  0.8500000000000000D+00 * w( 75)
      chem( 36) = chem( 36) +  0.1000000000000000D+00 * w( 75)
      chem( 37) = chem( 37) - w( 75)
      chem( 72) = chem( 72) +  0.5000000000000000D-01 * w( 75)
      chem( 75) = chem( 75) - w( 75)
      chem( 81) = chem( 81) +  0.5000000000000000D-01 * w( 75)
      chem( 60) = chem( 60) + w( 76)
      chem( 74) = chem( 74) - w( 76)
      chem( 75) = chem( 75) - w( 76)
      chem( 81) = chem( 81) + w( 76)
      chem( 71) = chem( 71) - w( 77)
      chem( 75) = chem( 75) - w( 77)
      chem( 76) = chem( 76) + w( 77)
      chem( 64) = chem( 64) + w( 78)
      chem( 69) = chem( 69) - w( 78)
      chem( 75) = chem( 75) - w( 78)
      chem( 41) = chem( 41) - w( 79)
      chem( 66) = chem( 66) + w( 79)
      chem( 75) = chem( 75) - w( 79)
      chem( 81) = chem( 81) + w( 79)
      chem( 60) = chem( 60) +  0.2000000000000000D+01 * w( 80)
      chem( 61) = chem( 61) - w( 80)
      chem( 75) = chem( 75) - w( 80)
      chem( 81) = chem( 81) + w( 80)
      chem( 60) = chem( 60) + w( 81)
      chem( 66) = chem( 66) - w( 81)
      chem( 75) = chem( 75) - w( 81)
      chem( 76) = chem( 76) + w( 81)
      chem( 41) = chem( 41) +  0.4100000000000000D+00 * w( 82)
      chem( 52) = chem( 52) - w( 82)
      chem( 60) = chem( 60) +  0.4100000000000000D+00 * w( 82)
      chem( 66) = chem( 66) +  0.8000000000000000D-01 * w( 82)
      chem( 72) = chem( 72) +  0.4900000000000000D+00 * w( 82)
      chem( 74) = chem( 74) +  0.8000000000000000D-01 * w( 82)
      chem( 75) = chem( 75) - w( 82)
      chem( 79) = chem( 79) +  0.5100000000000000D+00 * w( 82)
      chem( 81) = chem( 81) +  0.4900000000000000D+00 * w( 82)
      chem( 12) = chem( 12) +  0.3500000000000000D+00 * w( 83)
      chem( 46) = chem( 46) - w( 83)
      chem( 61) = chem( 61) +  0.1500000000000000D+00 * w( 83)
      chem( 66) = chem( 66) +  0.1500000000000000D+00 * w( 83)
      chem( 72) = chem( 72) +  0.5000000000000000D+00 * w( 83)
      chem( 75) = chem( 75) - w( 83)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w( 83)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w( 83)
      chem( 12) = chem( 12) - w( 84)
      chem( 69) = chem( 69) +  0.1200000000000000D+00 * w( 84)
      chem( 71) = chem( 71) +  0.8800000000000000D+00 * w( 84)
      chem( 75) = chem( 75) - w( 84)
      chem( 81) = chem( 81) + w( 84)
      chem( 25) = chem( 25) - w( 85)
      chem( 73) = chem( 73) +  0.6500000000000000D+00 * w( 85)
      chem( 74) = chem( 74) +  0.3500000000000000D+00 * w( 85)
      chem( 75) = chem( 75) -  0.6500000000000000D+00 * w( 85)
      chem( 65) = chem( 65) - w( 86)
      chem( 68) = chem( 68) +  0.4400000000000000D+00 * w( 86)
      chem( 69) = chem( 69) +  0.4100000000000000D+00 * w( 86)
      chem( 71) = chem( 71) +  0.8000000000000000D-01 * w( 86)
      chem( 72) = chem( 72) +  0.7000000000000001D-01 * w( 86)
      chem( 75) = chem( 75) -  0.5100000000000000D+00 * w( 86)
      chem( 35) = chem( 35) - w( 87)
      chem( 72) = chem( 72) +  0.3500000000000000D+00 * w( 87)
      chem( 74) = chem( 74) +  0.3500000000000000D+00 * w( 87)
      chem( 75) = chem( 75) - w( 87)
      chem( 76) = chem( 76) +  0.6500000000000000D+00 * w( 87)
      chem( 81) = chem( 81) +  0.3500000000000000D+00 * w( 87)
      chem( 44) = chem( 44) - w( 88)
      chem( 72) = chem( 72) + w( 88)
      chem( 74) = chem( 74) + w( 88)
      chem( 75) = chem( 75) - w( 88)
      chem( 77) = chem( 77) + w( 88)
      chem( 41) = chem( 41) +  0.6000000000000000D+00 * w( 89)
      chem( 42) = chem( 42) - w( 89)
      chem( 44) = chem( 44) +  0.4000000000000000D+00 * w( 89)
      chem( 72) = chem( 72) + w( 89)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w( 89)
      chem( 75) = chem( 75) - w( 89)
      chem( 77) = chem( 77) +  0.6000000000000000D+00 * w( 89)
      chem( 81) = chem( 81) +  0.4000000000000000D+00 * w( 89)
      chem( 68) = chem( 68) + w( 90)
      chem( 75) = chem( 75) - w( 90)
      chem( 80) = chem( 80) + w( 90)
      chem( 82) = chem( 82) - w( 90)
      chem( 60) = chem( 60) + w( 91)
      chem( 67) = chem( 67) + w( 91)
      chem( 74) = chem( 74) - w( 91)
      chem( 77) = chem( 77) - w( 91)
      chem( 81) = chem( 81) + w( 91)
      chem( 67) = chem( 67) + w( 92)
      chem( 71) = chem( 71) - w( 92)
      chem( 76) = chem( 76) + w( 92)
      chem( 77) = chem( 77) - w( 92)
      chem( 60) = chem( 60) +  0.2000000000000000D+01 * w( 93)
      chem( 61) = chem( 61) - w( 93)
      chem( 67) = chem( 67) + w( 93)
      chem( 77) = chem( 77) - w( 93)
      chem( 81) = chem( 81) + w( 93)
      chem( 60) = chem( 60) + w( 94)
      chem( 66) = chem( 66) - w( 94)
      chem( 67) = chem( 67) + w( 94)
      chem( 76) = chem( 76) + w( 94)
      chem( 77) = chem( 77) - w( 94)
      chem( 52) = chem( 52) - w( 95)
      chem( 57) = chem( 57) +  0.8000000000000000D+00 * w( 95)
      chem( 60) = chem( 60) +  0.8000000000000000D+00 * w( 95)
      chem( 67) = chem( 67) +  0.2000000000000000D+00 * w( 95)
      chem( 77) = chem( 77) - w( 95)
      chem( 79) = chem( 79) +  0.2000000000000000D+00 * w( 95)
      chem( 46) = chem( 46) - w( 96)
      chem( 61) = chem( 61) +  0.2500000000000000D+00 * w( 96)
      chem( 66) = chem( 66) +  0.2500000000000000D+00 * w( 96)
      chem( 67) = chem( 67) +  0.5000000000000000D+00 * w( 96)
      chem( 69) = chem( 69) +  0.3000000000000000D-01 * w( 96)
      chem( 71) = chem( 71) +  0.2500000000000000D+00 * w( 96)
      chem( 72) = chem( 72) +  0.5000000000000000D+00 * w( 96)
      chem( 77) = chem( 77) - w( 96)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w( 96)
      chem( 80) = chem( 80) +  0.5000000000000000D+00 * w( 96)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w( 96)
      chem( 19) = chem( 19) +  0.3900000000000000D-01 * w( 97)
      chem( 20) = chem( 20) +  0.1080000000000000D+00 * w( 97)
      chem( 36) = chem( 36) + w( 97)
      chem( 37) = chem( 37) - w( 97)
      chem( 67) = chem( 67) + w( 97)
      chem( 77) = chem( 77) - w( 97)
      chem( 27) = chem( 27) - w( 98)
      chem( 57) = chem( 57) +  0.8000000000000000D+00 * w( 98)
      chem( 58) = chem( 58) +  0.2000000000000000D+00 * w( 98)
      chem( 77) = chem( 77) - w( 98)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w( 99)
      chem( 53) = chem( 53) - w( 99)
      chem( 57) = chem( 57) +  0.4300000000000000D+00 * w( 99)
      chem( 58) = chem( 58) +  0.5700000000000000D+00 * w( 99)
      chem( 77) = chem( 77) - w( 99)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(100)
      chem( 56) = chem( 56) - w(100)
      chem( 57) = chem( 57) +  0.1100000000000000D+00 * w(100)
      chem( 58) = chem( 58) +  0.8900000000000000D+00 * w(100)
      chem( 77) = chem( 77) - w(100)
      chem( 21) = chem( 21) - w(101)
      chem( 52) = chem( 52) +  0.9000000000000000D+00 * w(101)
      chem( 57) = chem( 57) +  0.9000000000000000D+00 * w(101)
      chem( 58) = chem( 58) +  0.1000000000000000D+00 * w(101)
      chem( 77) = chem( 77) - w(101)
      chem( 28) = chem( 28) - w(102)
      chem( 52) = chem( 52) +  0.9000000000000000D+00 * w(102)
      chem( 57) = chem( 57) +  0.9000000000000000D+00 * w(102)
      chem( 58) = chem( 58) +  0.1000000000000000D+00 * w(102)
      chem( 77) = chem( 77) - w(102)
      chem( 26) = chem( 26) - w(103)
      chem( 57) = chem( 57) +  0.1000000000000000D+00 * w(103)
      chem( 58) = chem( 58) +  0.9000000000000000D+00 * w(103)
      chem( 77) = chem( 77) - w(103)
      chem( 14) = chem( 14) - w(104)
      chem( 57) = chem( 57) +  0.1300000000000000D+00 * w(104)
      chem( 58) = chem( 58) +  0.8700000000000000D+00 * w(104)
      chem( 77) = chem( 77) - w(104)
      chem( 42) = chem( 42) - w(105)
      chem( 44) = chem( 44) +  0.4000000000000000D+00 * w(105)
      chem( 72) = chem( 72) + w(105)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(105)
      chem( 77) = chem( 77) -  0.4000000000000000D+00 * w(105)
      chem( 80) = chem( 80) +  0.4000000000000000D+00 * w(105)
      chem( 82) = chem( 82) +  0.6000000000000000D+00 * w(105)
      chem( 27) = chem( 27) - w(106)
      chem( 43) = chem( 43) +  0.3700000000000000D+00 * w(106)
      chem( 59) = chem( 59) - w(106)
      chem( 60) = chem( 60) +  0.4300000000000000D+00 * w(106)
      chem( 74) = chem( 74) + w(106)
      chem( 75) = chem( 75) +  0.1200000000000000D+00 * w(106)
      chem( 81) = chem( 81) +  0.2600000000000000D+00 * w(106)
      chem( 29) = chem( 29) +  0.6000000000000000D-01 * w(107)
      chem( 30) = chem( 30) +  0.3000000000000000D-01 * w(107)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(107)
      chem( 43) = chem( 43) +  0.1400000000000000D+00 * w(107)
      chem( 45) = chem( 45) +  0.6000000000000000D-02 * w(107)
      chem( 53) = chem( 53) - w(107)
      chem( 59) = chem( 59) - w(107)
      chem( 60) = chem( 60) +  0.3700000000000000D+00 * w(107)
      chem( 63) = chem( 63) +  0.1000000000000000D+00 * w(107)
      chem( 64) = chem( 64) +  0.3000000000000000D-01 * w(107)
      chem( 69) = chem( 69) +  0.3000000000000000D-01 * w(107)
      chem( 70) = chem( 70) +  0.1000000000000000D+00 * w(107)
      chem( 71) = chem( 71) +  0.4400000000000000D+00 * w(107)
      chem( 73) = chem( 73) +  0.1900000000000000D+00 * w(107)
      chem( 74) = chem( 74) +  0.6400000000000000D+00 * w(107)
      chem( 75) = chem( 75) +  0.4000000000000000D+00 * w(107)
      chem( 81) = chem( 81) +  0.2500000000000000D+00 * w(107)
      chem( 29) = chem( 29) +  0.7000000000000001D-01 * w(108)
      chem( 30) = chem( 30) +  0.6000000000000000D-01 * w(108)
      chem( 38) = chem( 38) +  0.8000000000000000D-02 * w(108)
      chem( 45) = chem( 45) +  0.1100000000000000D-01 * w(108)
      chem( 56) = chem( 56) - w(108)
      chem( 59) = chem( 59) - w(108)
      chem( 60) = chem( 60) +  0.3000000000000000D+00 * w(108)
      chem( 63) = chem( 63) +  0.1400000000000000D+00 * w(108)
      chem( 64) = chem( 64) +  0.1200000000000000D+00 * w(108)
      chem( 69) = chem( 69) +  0.1600000000000000D+00 * w(108)
      chem( 70) = chem( 70) +  0.1800000000000000D+00 * w(108)
      chem( 71) = chem( 71) +  0.9900000000000000D+00 * w(108)
      chem( 73) = chem( 73) +  0.2300000000000000D+00 * w(108)
      chem( 74) = chem( 74) +  0.2000000000000000D-01 * w(108)
      chem( 75) = chem( 75) +  0.6300000000000000D+00 * w(108)
      chem( 81) = chem( 81) +  0.2200000000000000D+00 * w(108)
      chem( 21) = chem( 21) - w(109)
      chem( 34) = chem( 34) +  0.9000000000000000D-01 * w(109)
      chem( 43) = chem( 43) +  0.1500000000000000D+00 * w(109)
      chem( 45) = chem( 45) +  0.1000000000000000D-02 * w(109)
      chem( 52) = chem( 52) +  0.3900000000000000D+00 * w(109)
      chem( 53) = chem( 53) +  0.3500000000000000D+00 * w(109)
      chem( 59) = chem( 59) - w(109)
      chem( 60) = chem( 60) +  0.3600000000000000D+00 * w(109)
      chem( 64) = chem( 64) +  0.2000000000000000D-01 * w(109)
      chem( 72) = chem( 72) +  0.1300000000000000D+00 * w(109)
      chem( 73) = chem( 73) +  0.3000000000000000D-01 * w(109)
      chem( 74) = chem( 74) +  0.9000000000000000D+00 * w(109)
      chem( 75) = chem( 75) +  0.2800000000000000D+00 * w(109)
      chem( 76) = chem( 76) +  0.1500000000000000D+00 * w(109)
      chem( 81) = chem( 81) +  0.3000000000000000D+00 * w(109)
      chem( 28) = chem( 28) - w(110)
      chem( 34) = chem( 34) +  0.9000000000000000D-01 * w(110)
      chem( 43) = chem( 43) +  0.1500000000000000D+00 * w(110)
      chem( 45) = chem( 45) +  0.1000000000000000D-02 * w(110)
      chem( 52) = chem( 52) +  0.3900000000000000D+00 * w(110)
      chem( 53) = chem( 53) +  0.3500000000000000D+00 * w(110)
      chem( 59) = chem( 59) - w(110)
      chem( 60) = chem( 60) +  0.3600000000000000D+00 * w(110)
      chem( 64) = chem( 64) +  0.2000000000000000D-01 * w(110)
      chem( 72) = chem( 72) +  0.1300000000000000D+00 * w(110)
      chem( 73) = chem( 73) +  0.3000000000000000D-01 * w(110)
      chem( 74) = chem( 74) +  0.9000000000000000D+00 * w(110)
      chem( 75) = chem( 75) +  0.2800000000000000D+00 * w(110)
      chem( 76) = chem( 76) +  0.1500000000000000D+00 * w(110)
      chem( 81) = chem( 81) +  0.3000000000000000D+00 * w(110)
      chem( 22) = chem( 22) +  0.2158800000000000D-01 * w(111)
      chem( 23) = chem( 23) +  0.1858110000000000D+00 * w(111)
      chem( 26) = chem( 26) - w(111)
      chem( 45) = chem( 45) +  0.2000000000000000D-01 * w(111)
      chem( 59) = chem( 59) - w(111)
      chem( 60) = chem( 60) +  0.1400000000000000D+00 * w(111)
      chem( 64) = chem( 64) +  0.4200000000000000D+00 * w(111)
      chem( 69) = chem( 69) +  0.5300000000000000D+00 * w(111)
      chem( 70) = chem( 70) +  0.2000000000000000D+00 * w(111)
      chem( 71) = chem( 71) +  0.6500000000000000D+00 * w(111)
      chem( 75) = chem( 75) +  0.8500000000000000D+00 * w(111)
      chem( 81) = chem( 81) +  0.1000000000000000D+00 * w(111)
      chem( 14) = chem( 14) - w(112)
      chem( 15) = chem( 15) +  0.1256730000000000D+00 * w(112)
      chem( 16) = chem( 16) +  0.1904370000000000D+00 * w(112)
      chem( 43) = chem( 43) +  0.1000000000000000D-01 * w(112)
      chem( 45) = chem( 45) +  0.2000000000000000D-01 * w(112)
      chem( 52) = chem( 52) +  0.7900000000000000D+00 * w(112)
      chem( 53) = chem( 53) +  0.4600000000000000D+00 * w(112)
      chem( 59) = chem( 59) - w(112)
      chem( 60) = chem( 60) +  0.1400000000000000D+00 * w(112)
      chem( 63) = chem( 63) +  0.7000000000000001D-01 * w(112)
      chem( 64) = chem( 64) +  0.4200000000000000D+00 * w(112)
      chem( 70) = chem( 70) +  0.1600000000000000D+00 * w(112)
      chem( 74) = chem( 74) +  0.4000000000000000D-01 * w(112)
      chem( 75) = chem( 75) +  0.8500000000000000D+00 * w(112)
      chem( 81) = chem( 81) +  0.1000000000000000D+00 * w(112)
      chem( 43) = chem( 43) +  0.2200000000000000D+00 * w(113)
      chem( 52) = chem( 52) - w(113)
      chem( 59) = chem( 59) - w(113)
      chem( 60) = chem( 60) +  0.5400000000000000D+00 * w(113)
      chem( 63) = chem( 63) +  0.1300000000000000D+00 * w(113)
      chem( 65) = chem( 65) +  0.1300000000000000D+00 * w(113)
      chem( 66) = chem( 66) +  0.6000000000000000D+00 * w(113)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(113)
      chem( 75) = chem( 75) +  0.7000000000000001D-01 * w(113)
      chem( 76) = chem( 76) +  0.1300000000000000D+00 * w(113)
      chem( 81) = chem( 81) +  0.2900000000000000D+00 * w(113)
      chem( 35) = chem( 35) +  0.1100000000000000D+00 * w(114)
      chem( 43) = chem( 43) +  0.1100000000000000D+00 * w(114)
      chem( 46) = chem( 46) - w(114)
      chem( 59) = chem( 59) - w(114)
      chem( 60) = chem( 60) +  0.6600000000000000D+00 * w(114)
      chem( 61) = chem( 61) +  0.5000000000000000D+00 * w(114)
      chem( 63) = chem( 63) +  0.2100000000000000D+00 * w(114)
      chem( 66) = chem( 66) +  0.6200000000000000D+00 * w(114)
      chem( 71) = chem( 71) +  0.1600000000000000D+00 * w(114)
      chem( 75) = chem( 75) +  0.2100000000000000D+00 * w(114)
      chem( 76) = chem( 76) +  0.2800000000000000D+00 * w(114)
      chem( 81) = chem( 81) +  0.2900000000000000D+00 * w(114)
      chem( 42) = chem( 42) - w(115)
      chem( 43) = chem( 43) +  0.1100000000000000D+00 * w(115)
      chem( 44) = chem( 44) +  0.3000000000000000D+00 * w(115)
      chem( 59) = chem( 59) - w(115)
      chem( 60) = chem( 60) +  0.1300000000000000D+00 * w(115)
      chem( 74) = chem( 74) +  0.7000000000000000D+00 * w(115)
      chem( 75) = chem( 75) +  0.3600000000000000D-01 * w(115)
      chem( 76) = chem( 76) +  0.7000000000000000D+00 * w(115)
      chem( 80) = chem( 80) +  0.7000000000000000D+00 * w(115)
      chem( 81) = chem( 81) +  0.8000000000000000D-01 * w(115)
      chem( 36) = chem( 36) - w(116)
      chem( 37) = chem( 37) +  0.1000000000000000D+00 * w(116)
      chem( 80) = chem( 80) - w(116)
      chem( 82) = chem( 82) + w(116)
      chem( 36) = chem( 36) - w(117)
      chem( 37) = chem( 37) + w(117)
      chem( 81) = chem( 81) - w(117)
      chem( 17) = chem( 17) - w(118)
      chem( 32) = chem( 32) + w(118)
      chem( 37) = chem( 37) + w(118)
      chem( 80) = chem( 80) - w(118)
      chem( 17) = chem( 17) - w(119)
      chem( 37) = chem( 37) +  0.2000000000000000D-01 * w(119)
      chem( 39) = chem( 39) +  0.9800000000000000D+00 * w(119)
      chem( 81) = chem( 81) +  0.2000000000000000D-01 * w(119)
      chem( 17) = chem( 17) - w(120)
      chem( 37) = chem( 37) + w(120)
      chem( 59) = chem( 59) - w(120)
      chem( 75) = chem( 75) + w(120)
      chem( 18) = chem( 18) - w(121)
      chem( 32) = chem( 32) + w(121)
      chem( 37) = chem( 37) + w(121)
      chem( 80) = chem( 80) - w(121)
      chem( 18) = chem( 18) - w(122)
      chem( 37) = chem( 37) +  0.2000000000000000D-01 * w(122)
      chem( 40) = chem( 40) +  0.9800000000000000D+00 * w(122)
      chem( 81) = chem( 81) +  0.2000000000000000D-01 * w(122)
      chem( 18) = chem( 18) - w(123)
      chem( 37) = chem( 37) + w(123)
      chem( 59) = chem( 59) - w(123)
      chem( 75) = chem( 75) + w(123)
      chem( 31) = chem( 31) - w(124)
      chem( 32) = chem( 32) + w(124)
      chem( 37) = chem( 37) + w(124)
      chem( 80) = chem( 80) - w(124)
      chem( 31) = chem( 31) - w(125)
      chem( 33) = chem( 33) +  0.9800000000000000D+00 * w(125)
      chem( 37) = chem( 37) +  0.2000000000000000D-01 * w(125)
      chem( 81) = chem( 81) +  0.2000000000000000D-01 * w(125)
      chem( 31) = chem( 31) - w(126)
      chem( 37) = chem( 37) + w(126)
      chem( 59) = chem( 59) - w(126)
      chem( 75) = chem( 75) + w(126)
      chem( 44) = chem( 44) + w(127)
      chem( 76) = chem( 76) - w(127)
      chem( 80) = chem( 80) - w(127)
      chem( 44) = chem( 44) - w(128)
      chem( 76) = chem( 76) + w(128)
      chem( 80) = chem( 80) + w(128)
      chem( 42) = chem( 42) + w(129)
      chem( 79) = chem( 79) - w(129)
      chem( 80) = chem( 80) - w(129)
      chem( 42) = chem( 42) - w(130)
      chem( 79) = chem( 79) + w(130)
      chem( 80) = chem( 80) + w(130)
      chem( 73) = chem( 73) - w(131)
      chem( 74) = chem( 74) + w(131)
      chem( 78) = chem( 78) - w(131)
      chem( 80) = chem( 80) + w(131)
      chem( 81) = chem( 81) + w(131)
      chem( 70) = chem( 70) - w(132)
      chem( 71) = chem( 71) + w(132)
      chem( 78) = chem( 78) - w(132)
      chem( 80) = chem( 80) + w(132)
      chem( 81) = chem( 81) + w(132)
      chem( 61) = chem( 61) +  0.6300000000000000D-01 * w(133)
      chem( 68) = chem( 68) - w(133)
      chem( 69) = chem( 69) +  0.6230000000000000D+00 * w(133)
      chem( 70) = chem( 70) +  0.4800000000000000D-01 * w(133)
      chem( 71) = chem( 71) +  0.2330000000000000D+00 * w(133)
      chem( 72) = chem( 72) +  0.4800000000000000D-01 * w(133)
      chem( 73) = chem( 73) +  0.1500000000000000D+00 * w(133)
      chem( 74) = chem( 74) +  0.4700000000000000D-01 * w(133)
      chem( 78) = chem( 78) - w(133)
      chem( 80) = chem( 80) +  0.9409999999999999D+00 * w(133)
      chem( 81) = chem( 81) +  0.7420000000000000D+00 * w(133)
      chem( 82) = chem( 82) +  0.5900000000000000D-01 * w(133)
      chem( 48) = chem( 48) - w(134)
      chem( 69) = chem( 69) +  0.7220000000000000D+00 * w(134)
      chem( 70) = chem( 70) +  0.2450000000000000D+00 * w(134)
      chem( 71) = chem( 71) +  0.2110000000000000D+00 * w(134)
      chem( 72) = chem( 72) +  0.3340000000000000D+00 * w(134)
      chem( 73) = chem( 73) +  0.3100000000000000D-01 * w(134)
      chem( 74) = chem( 74) +  0.2100000000000000D-01 * w(134)
      chem( 78) = chem( 78) - w(134)
      chem( 80) = chem( 80) +  0.8760000000000000D+00 * w(134)
      chem( 81) = chem( 81) +  0.5990000000000000D+00 * w(134)
      chem( 82) = chem( 82) +  0.1240000000000000D+00 * w(134)
      chem( 49) = chem( 49) - w(135)
      chem( 69) = chem( 69) +  0.6420000000000000D+00 * w(135)
      chem( 70) = chem( 70) +  0.1330000000000000D+00 * w(135)
      chem( 71) = chem( 71) +  0.1500000000000000D+00 * w(135)
      chem( 72) = chem( 72) +  0.4160000000000000D+00 * w(135)
      chem( 78) = chem( 78) - w(135)
      chem( 80) = chem( 80) +  0.7390000000000000D+00 * w(135)
      chem( 81) = chem( 81) +  0.6060000000000000D+00 * w(135)
      chem( 82) = chem( 82) +  0.2610000000000000D+00 * w(135)
      chem( 50) = chem( 50) - w(136)
      chem( 71) = chem( 71) +  0.2000000000000000D+00 * w(136)
      chem( 74) = chem( 74) +  0.1600000000000000D+01 * w(136)
      chem( 78) = chem( 78) - w(136)
      chem( 80) = chem( 80) + w(136)
      chem( 81) = chem( 81) + w(136)
      chem( 54) = chem( 54) - w(137)
      chem( 69) = chem( 69) +  0.6000000000000000D-01 * w(137)
      chem( 71) = chem( 71) +  0.9399999999999999D+00 * w(137)
      chem( 74) = chem( 74) + w(137)
      chem( 78) = chem( 78) - w(137)
      chem( 80) = chem( 80) + w(137)
      chem( 81) = chem( 81) + w(137)
      chem( 62) = chem( 62) - w(138)
      chem( 69) = chem( 69) +  0.2900000000000000D+00 * w(138)
      chem( 71) = chem( 71) +  0.1710000000000000D+01 * w(138)
      chem( 78) = chem( 78) - w(138)
      chem( 80) = chem( 80) + w(138)
      chem( 81) = chem( 81) + w(138)
      chem( 51) = chem( 51) - w(139)
      chem( 52) = chem( 52) +  0.4460000000000000D+00 * w(139)
      chem( 53) = chem( 53) +  0.3540000000000000D+00 * w(139)
      chem( 74) = chem( 74) +  0.6060000000000000D+00 * w(139)
      chem( 78) = chem( 78) - w(139)
      chem( 80) = chem( 80) +  0.8470000000000000D+00 * w(139)
      chem( 81) = chem( 81) +  0.8470000000000000D+00 * w(139)
      chem( 82) = chem( 82) +  0.1530000000000000D+00 * w(139)
      chem( 55) = chem( 55) - w(140)
      chem( 69) = chem( 69) +  0.8000000000000000D+00 * w(140)
      chem( 71) = chem( 71) +  0.8000000000000000D+00 * w(140)
      chem( 78) = chem( 78) - w(140)
      chem( 80) = chem( 80) +  0.8000000000000000D+00 * w(140)
      chem( 81) = chem( 81) +  0.8000000000000000D+00 * w(140)
      chem( 82) = chem( 82) +  0.2000000000000000D+00 * w(140)
      chem( 47) = chem( 47) - w(141)
      chem( 52) = chem( 52) +  0.4000000000000000D+00 * w(141)
      chem( 56) = chem( 56) +  0.2500000000000000D+00 * w(141)
      chem( 74) = chem( 74) +  0.2500000000000000D+00 * w(141)
      chem( 78) = chem( 78) - w(141)
      chem( 80) = chem( 80) +  0.6500000000000000D+00 * w(141)
      chem( 81) = chem( 81) +  0.6500000000000000D+00 * w(141)
      chem( 82) = chem( 82) +  0.3500000000000000D+00 * w(141)
      chem( 39) = chem( 39) - w(142)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(142)
      chem( 61) = chem( 61) +  0.1200000000000000D+01 * w(142)
      chem( 66) = chem( 66) +  0.6500000000000000D+00 * w(142)
      chem( 78) = chem( 78) - w(142)
      chem( 80) = chem( 80) +  0.9500000000000000D+00 * w(142)
      chem( 81) = chem( 81) +  0.9500000000000000D+00 * w(142)
      chem( 82) = chem( 82) +  0.5000000000000000D-01 * w(142)
      chem( 40) = chem( 40) - w(143)
      chem( 46) = chem( 46) +  0.9500000000000000D+00 * w(143)
      chem( 61) = chem( 61) +  0.3500000000000000D+00 * w(143)
      chem( 66) = chem( 66) +  0.6000000000000000D+00 * w(143)
      chem( 78) = chem( 78) - w(143)
      chem( 80) = chem( 80) +  0.9500000000000000D+00 * w(143)
      chem( 81) = chem( 81) +  0.9500000000000000D+00 * w(143)
      chem( 82) = chem( 82) +  0.5000000000000000D-01 * w(143)
      chem( 33) = chem( 33) - w(144)
      chem( 61) = chem( 61) + w(144)
      chem( 66) = chem( 66) + w(144)
      chem( 78) = chem( 78) - w(144)
      chem( 80) = chem( 80) + w(144)
      chem( 81) = chem( 81) + w(144)
      chem( 73) = chem( 73) + w(145)
      chem( 76) = chem( 76) - w(145)
      chem( 78) = chem( 78) - w(145)
      chem( 80) = chem( 80) + w(145)
      chem( 74) = chem( 74) + w(146)
      chem( 76) = chem( 76) + w(146)
      chem( 78) = chem( 78) - w(146)
      chem( 79) = chem( 79) - w(146)
      chem( 80) = chem( 80) + w(146)
      chem( 64) = chem( 64) - w(147)
      chem( 66) = chem( 66) +  0.5400000000000000D+00 * w(147)
      chem( 71) = chem( 71) +  0.4600000000000000D+00 * w(147)
      chem( 72) = chem( 72) +  0.1600000000000000D+00 * w(147)
      chem( 76) = chem( 76) +  0.2300000000000000D+00 * w(147)
      chem( 78) = chem( 78) - w(147)
      chem( 80) = chem( 80) + w(147)
      chem( 81) = chem( 81) +  0.7700000000000000D+00 * w(147)
      chem( 57) = chem( 57) - w(148)
      chem( 78) = chem( 78) - w(148)
      chem( 80) = chem( 80) + w(148)
      chem( 81) = chem( 81) + w(148)
      chem( 82) = chem( 82) + w(148)
      chem( 58) = chem( 58) - w(149)
      chem( 69) = chem( 69) +  0.4640000000000000D+00 * w(149)
      chem( 71) = chem( 71) +  0.1240000000000000D+01 * w(149)
      chem( 74) = chem( 74) +  0.2870000000000000D+00 * w(149)
      chem( 78) = chem( 78) - w(149)
      chem( 80) = chem( 80) +  0.2000000000000000D+01 * w(149)
      chem( 25) = chem( 25) + w(150)
      chem( 73) = chem( 73) - w(150)
      chem( 81) = chem( 81) - w(150)
      chem( 65) = chem( 65) + w(151)
      chem( 70) = chem( 70) - w(151)
      chem( 81) = chem( 81) - w(151)
      chem( 65) = chem( 65) + w(152)
      chem( 68) = chem( 68) - w(152)
      chem( 81) = chem( 81) - w(152)
      chem( 48) = chem( 48) - w(153)
      chem( 65) = chem( 65) + w(153)
      chem( 81) = chem( 81) - w(153)
      chem( 49) = chem( 49) - w(154)
      chem( 65) = chem( 65) + w(154)
      chem( 81) = chem( 81) - w(154)
      chem( 50) = chem( 50) - w(155)
      chem( 65) = chem( 65) + w(155)
      chem( 81) = chem( 81) - w(155)
      chem( 54) = chem( 54) - w(156)
      chem( 65) = chem( 65) + w(156)
      chem( 81) = chem( 81) - w(156)
      chem( 62) = chem( 62) - w(157)
      chem( 65) = chem( 65) + w(157)
      chem( 81) = chem( 81) - w(157)
      chem( 51) = chem( 51) - w(158)
      chem( 65) = chem( 65) + w(158)
      chem( 81) = chem( 81) - w(158)
      chem( 55) = chem( 55) - w(159)
      chem( 65) = chem( 65) + w(159)
      chem( 81) = chem( 81) - w(159)
      chem( 47) = chem( 47) - w(160)
      chem( 65) = chem( 65) + w(160)
      chem( 81) = chem( 81) - w(160)
      chem( 39) = chem( 39) - w(161)
      chem( 65) = chem( 65) + w(161)
      chem( 81) = chem( 81) - w(161)
      chem( 40) = chem( 40) - w(162)
      chem( 65) = chem( 65) + w(162)
      chem( 81) = chem( 81) - w(162)
      chem( 33) = chem( 33) - w(163)
      chem( 65) = chem( 65) + w(163)
      chem( 81) = chem( 81) - w(163)
      chem( 35) = chem( 35) + w(164)
      chem( 76) = chem( 76) - w(164)
      chem( 81) = chem( 81) - w(164)
      chem( 59) = chem( 59) + w(165)
      chem( 63) = chem( 63) + w(165)
      chem( 76) = chem( 76) - w(165)
      chem( 81) = chem( 81) - w(165)
      chem( 65) = chem( 65) + w(166)
      chem( 79) = chem( 79) - w(166)
      chem( 81) = chem( 81) - w(166)
      chem( 59) = chem( 59) + w(167)
      chem( 63) = chem( 63) + w(167)
      chem( 79) = chem( 79) - w(167)
      chem( 81) = chem( 81) - w(167)
      chem( 64) = chem( 64) - w(168)
      chem( 65) = chem( 65) + w(168)
      chem( 81) = chem( 81) - w(168)
      chem( 57) = chem( 57) - w(169)
      chem( 81) = chem( 81) - w(169)
      chem( 82) = chem( 82) + w(169)
      chem( 58) = chem( 58) - w(170)
      chem( 81) = chem( 81) - w(170)
      chem( 82) = chem( 82) + w(170)
      chem( 73) = chem( 73) -  0.2000000000000000D+01 * w(171)
      chem( 74) = chem( 74) +  0.1330000000000000D+01 * w(171)
      chem( 81) = chem( 81) +  0.6600000000000000D+00 * w(171)
      chem( 70) = chem( 70) - w(172)
      chem( 71) = chem( 71) +  0.7500000000000000D+00 * w(172)
      chem( 73) = chem( 73) - w(172)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(172)
      chem( 81) = chem( 81) + w(172)
      chem( 61) = chem( 61) +  0.1190000000000000D+00 * w(173)
      chem( 66) = chem( 66) +  0.5000000000000000D-02 * w(173)
      chem( 68) = chem( 68) - w(173)
      chem( 69) = chem( 69) +  0.1800000000000000D-01 * w(173)
      chem( 71) = chem( 71) +  0.5800000000000000D+00 * w(173)
      chem( 72) = chem( 72) +  0.8500000000000001D-01 * w(173)
      chem( 73) = chem( 73) -  0.9930000000000000D+00 * w(173)
      chem( 74) = chem( 74) +  0.8100000000000001D+00 * w(173)
      chem( 81) = chem( 81) +  0.9920000000000000D+00 * w(173)
      chem( 48) = chem( 48) - w(174)
      chem( 69) = chem( 69) +  0.2400000000000000D+00 * w(174)
      chem( 70) = chem( 70) +  0.1400000000000000D-01 * w(174)
      chem( 71) = chem( 71) +  0.5230000000000000D+00 * w(174)
      chem( 72) = chem( 72) +  0.2450000000000000D+00 * w(174)
      chem( 73) = chem( 73) -  0.9510000000000000D+00 * w(174)
      chem( 74) = chem( 74) +  0.8290000000000000D+00 * w(174)
      chem( 81) = chem( 81) +  0.9460000000000000D+00 * w(174)
      chem( 49) = chem( 49) - w(175)
      chem( 69) = chem( 69) +  0.4190000000000000D+00 * w(175)
      chem( 70) = chem( 70) +  0.1300000000000000D-01 * w(175)
      chem( 71) = chem( 71) +  0.4110000000000000D+00 * w(175)
      chem( 72) = chem( 72) +  0.3220000000000000D+00 * w(175)
      chem( 73) = chem( 73) - w(175)
      chem( 74) = chem( 74) +  0.7530000000000000D+00 * w(175)
      chem( 81) = chem( 81) +  0.9930000000000000D+00 * w(175)
      chem( 50) = chem( 50) - w(176)
      chem( 71) = chem( 71) +  0.3500000000000000D+00 * w(176)
      chem( 73) = chem( 73) - w(176)
      chem( 74) = chem( 74) +  0.1550000000000000D+01 * w(176)
      chem( 81) = chem( 81) + w(176)
      chem( 54) = chem( 54) - w(177)
      chem( 69) = chem( 69) +  0.8100000000000000D-01 * w(177)
      chem( 71) = chem( 71) +  0.6690000000000000D+00 * w(177)
      chem( 73) = chem( 73) - w(177)
      chem( 74) = chem( 74) +  0.1250000000000000D+01 * w(177)
      chem( 81) = chem( 81) + w(177)
      chem( 62) = chem( 62) - w(178)
      chem( 69) = chem( 69) +  0.3130000000000000D+00 * w(178)
      chem( 71) = chem( 71) +  0.9320000000000001D+00 * w(178)
      chem( 73) = chem( 73) - w(178)
      chem( 74) = chem( 74) +  0.7550000000000000D+00 * w(178)
      chem( 81) = chem( 81) + w(178)
      chem( 51) = chem( 51) - w(179)
      chem( 52) = chem( 52) +  0.5500000000000000D+00 * w(179)
      chem( 53) = chem( 53) +  0.3700000000000000D+00 * w(179)
      chem( 56) = chem( 56) +  0.8000000000000000D-01 * w(179)
      chem( 73) = chem( 73) - w(179)
      chem( 74) = chem( 74) +  0.1090000000000000D+01 * w(179)
      chem( 81) = chem( 81) + w(179)
      chem( 55) = chem( 55) - w(180)
      chem( 69) = chem( 69) + w(180)
      chem( 71) = chem( 71) + w(180)
      chem( 73) = chem( 73) - w(180)
      chem( 74) = chem( 74) + w(180)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w(180)
      chem( 47) = chem( 47) - w(181)
      chem( 52) = chem( 52) +  0.6000000000000000D+00 * w(181)
      chem( 56) = chem( 56) +  0.4000000000000000D+00 * w(181)
      chem( 73) = chem( 73) - w(181)
      chem( 74) = chem( 74) +  0.1400000000000000D+01 * w(181)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w(181)
      chem( 39) = chem( 39) - w(182)
      chem( 46) = chem( 46) + w(182)
      chem( 61) = chem( 61) +  0.6500000000000000D+00 * w(182)
      chem( 66) = chem( 66) +  0.3500000000000000D+00 * w(182)
      chem( 73) = chem( 73) - w(182)
      chem( 74) = chem( 74) + w(182)
      chem( 81) = chem( 81) + w(182)
      chem( 40) = chem( 40) - w(183)
      chem( 46) = chem( 46) + w(183)
      chem( 61) = chem( 61) +  0.3700000000000000D+00 * w(183)
      chem( 66) = chem( 66) +  0.6300000000000000D+00 * w(183)
      chem( 73) = chem( 73) - w(183)
      chem( 74) = chem( 74) + w(183)
      chem( 81) = chem( 81) + w(183)
      chem( 33) = chem( 33) - w(184)
      chem( 61) = chem( 61) + w(184)
      chem( 66) = chem( 66) + w(184)
      chem( 73) = chem( 73) - w(184)
      chem( 74) = chem( 74) + w(184)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w(184)
      chem( 74) = chem( 74) + w(185)
      chem( 76) = chem( 76) - w(185)
      chem( 81) = chem( 81) + w(185)
      chem( 63) = chem( 63) + w(186)
      chem( 73) = chem( 73) - w(186)
      chem( 74) = chem( 74) + w(186)
      chem( 76) = chem( 76) - w(186)
      chem( 73) = chem( 73) - w(187)
      chem( 74) = chem( 74) +  0.2000000000000000D+01 * w(187)
      chem( 76) = chem( 76) + w(187)
      chem( 79) = chem( 79) - w(187)
      chem( 81) = chem( 81) + w(187)
      chem( 63) = chem( 63) + w(188)
      chem( 73) = chem( 73) - w(188)
      chem( 74) = chem( 74) + w(188)
      chem( 79) = chem( 79) - w(188)
      chem( 41) = chem( 41) +  0.3000000000000000D+00 * w(189)
      chem( 64) = chem( 64) - w(189)
      chem( 66) = chem( 66) +  0.4000000000000000D+00 * w(189)
      chem( 71) = chem( 71) +  0.3000000000000000D+00 * w(189)
      chem( 72) = chem( 72) +  0.8000000000000000D-01 * w(189)
      chem( 73) = chem( 73) - w(189)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(189)
      chem( 76) = chem( 76) +  0.1200000000000000D+00 * w(189)
      chem( 81) = chem( 81) +  0.8800000000000000D+00 * w(189)
      chem( 57) = chem( 57) - w(190)
      chem( 73) = chem( 73) - w(190)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(190)
      chem( 81) = chem( 81) + w(190)
      chem( 82) = chem( 82) + w(190)
      chem( 58) = chem( 58) - w(191)
      chem( 69) = chem( 69) +  0.1490000000000000D+00 * w(191)
      chem( 71) = chem( 71) +  0.6400000000000000D+00 * w(191)
      chem( 73) = chem( 73) - w(191)
      chem( 74) = chem( 74) +  0.9600000000000000D+00 * w(191)
      chem( 80) = chem( 80) +  0.5000000000000000D+00 * w(191)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w(191)
      chem( 82) = chem( 82) +  0.5000000000000000D+00 * w(191)
      chem( 63) = chem( 63) +  0.5000000000000000D+00 * w(192)
      chem( 70) = chem( 70) - w(192)
      chem( 71) = chem( 71) + w(192)
      chem( 73) = chem( 73) +  0.5000000000000000D+00 * w(192)
      chem( 76) = chem( 76) - w(192)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w(192)
      chem( 61) = chem( 61) +  0.1000000000000000D+00 * w(193)
      chem( 63) = chem( 63) +  0.4990000000000000D+00 * w(193)
      chem( 66) = chem( 66) +  0.4000000000000000D-02 * w(193)
      chem( 68) = chem( 68) - w(193)
      chem( 69) = chem( 69) +  0.1270000000000000D+00 * w(193)
      chem( 70) = chem( 70) +  0.6000000000000000D-02 * w(193)
      chem( 71) = chem( 71) +  0.7240000000000000D+00 * w(193)
      chem( 72) = chem( 72) +  0.7099999999999999D-01 * w(193)
      chem( 73) = chem( 73) +  0.5080000000000000D+00 * w(193)
      chem( 74) = chem( 74) +  0.9100000000000000D-01 * w(193)
      chem( 76) = chem( 76) - w(193)
      chem( 81) = chem( 81) +  0.4880000000000000D+00 * w(193)
      chem( 48) = chem( 48) - w(194)
      chem( 63) = chem( 63) +  0.4950000000000000D+00 * w(194)
      chem( 69) = chem( 69) +  0.3300000000000000D+00 * w(194)
      chem( 70) = chem( 70) +  0.1800000000000000D-01 * w(194)
      chem( 71) = chem( 71) +  0.6770000000000000D+00 * w(194)
      chem( 72) = chem( 72) +  0.2370000000000000D+00 * w(194)
      chem( 73) = chem( 73) +  0.5540000000000000D+00 * w(194)
      chem( 74) = chem( 74) +  0.7600000000000000D-01 * w(194)
      chem( 76) = chem( 76) - w(194)
      chem( 81) = chem( 81) +  0.4380000000000000D+00 * w(194)
      chem( 49) = chem( 49) - w(195)
      chem( 63) = chem( 63) +  0.4950000000000000D+00 * w(195)
      chem( 69) = chem( 69) +  0.5810000000000000D+00 * w(195)
      chem( 70) = chem( 70) +  0.1500000000000000D-01 * w(195)
      chem( 71) = chem( 71) +  0.4970000000000000D+00 * w(195)
      chem( 72) = chem( 72) +  0.3180000000000000D+00 * w(195)
      chem( 73) = chem( 73) +  0.5070000000000000D+00 * w(195)
      chem( 76) = chem( 76) - w(195)
      chem( 81) = chem( 81) +  0.4890000000000000D+00 * w(195)
      chem( 50) = chem( 50) - w(196)
      chem( 63) = chem( 63) +  0.5000000000000000D+00 * w(196)
      chem( 71) = chem( 71) +  0.6000000000000000D+00 * w(196)
      chem( 73) = chem( 73) +  0.5000000000000000D+00 * w(196)
      chem( 74) = chem( 74) +  0.8000000000000000D+00 * w(196)
      chem( 76) = chem( 76) - w(196)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w(196)
      chem( 54) = chem( 54) - w(197)
      chem( 63) = chem( 63) +  0.4990000000000000D+00 * w(197)
      chem( 69) = chem( 69) +  0.1410000000000000D+00 * w(197)
      chem( 71) = chem( 71) +  0.8590000000000000D+00 * w(197)
      chem( 73) = chem( 73) +  0.5010000000000000D+00 * w(197)
      chem( 74) = chem( 74) +  0.5010000000000000D+00 * w(197)
      chem( 76) = chem( 76) - w(197)
      chem( 81) = chem( 81) +  0.5010000000000000D+00 * w(197)
      chem( 62) = chem( 62) - w(198)
      chem( 63) = chem( 63) +  0.4900000000000000D+00 * w(198)
      chem( 69) = chem( 69) +  0.5690000000000000D+00 * w(198)
      chem( 71) = chem( 71) +  0.9409999999999999D+00 * w(198)
      chem( 73) = chem( 73) +  0.5100000000000000D+00 * w(198)
      chem( 76) = chem( 76) - w(198)
      chem( 81) = chem( 81) +  0.5100000000000000D+00 * w(198)
      chem( 51) = chem( 51) - w(199)
      chem( 52) = chem( 52) +  0.7710000000000000D+00 * w(199)
      chem( 53) = chem( 53) +  0.2290000000000000D+00 * w(199)
      chem( 63) = chem( 63) +  0.4940000000000000D+00 * w(199)
      chem( 73) = chem( 73) +  0.5060000000000000D+00 * w(199)
      chem( 74) = chem( 74) +  0.3400000000000000D+00 * w(199)
      chem( 76) = chem( 76) - w(199)
      chem( 81) = chem( 81) +  0.5060000000000000D+00 * w(199)
      chem( 55) = chem( 55) - w(200)
      chem( 69) = chem( 69) + w(200)
      chem( 71) = chem( 71) + w(200)
      chem( 73) = chem( 73) + w(200)
      chem( 76) = chem( 76) - w(200)
      chem( 81) = chem( 81) + w(200)
      chem( 47) = chem( 47) - w(201)
      chem( 52) = chem( 52) +  0.6000000000000000D+00 * w(201)
      chem( 56) = chem( 56) +  0.4000000000000000D+00 * w(201)
      chem( 73) = chem( 73) + w(201)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(201)
      chem( 76) = chem( 76) - w(201)
      chem( 81) = chem( 81) + w(201)
      chem( 39) = chem( 39) - w(202)
      chem( 46) = chem( 46) + w(202)
      chem( 61) = chem( 61) +  0.6500000000000000D+00 * w(202)
      chem( 66) = chem( 66) +  0.3500000000000000D+00 * w(202)
      chem( 73) = chem( 73) + w(202)
      chem( 76) = chem( 76) - w(202)
      chem( 81) = chem( 81) + w(202)
      chem( 40) = chem( 40) - w(203)
      chem( 46) = chem( 46) + w(203)
      chem( 61) = chem( 61) +  0.3700000000000000D+00 * w(203)
      chem( 66) = chem( 66) +  0.6300000000000000D+00 * w(203)
      chem( 73) = chem( 73) + w(203)
      chem( 76) = chem( 76) - w(203)
      chem( 81) = chem( 81) + w(203)
      chem( 33) = chem( 33) - w(204)
      chem( 61) = chem( 61) + w(204)
      chem( 66) = chem( 66) + w(204)
      chem( 73) = chem( 73) + w(204)
      chem( 76) = chem( 76) - w(204)
      chem( 81) = chem( 81) + w(204)
      chem( 73) = chem( 73) +  0.2000000000000000D+01 * w(205)
      chem( 76) = chem( 76) -  0.2000000000000000D+01 * w(205)
      chem( 73) = chem( 73) + w(206)
      chem( 74) = chem( 74) + w(206)
      chem( 79) = chem( 79) - w(206)
      chem( 63) = chem( 63) +  0.5000000000000000D+00 * w(207)
      chem( 64) = chem( 64) - w(207)
      chem( 66) = chem( 66) +  0.5400000000000000D+00 * w(207)
      chem( 69) = chem( 69) +  0.1100000000000000D+00 * w(207)
      chem( 71) = chem( 71) +  0.3500000000000000D+00 * w(207)
      chem( 72) = chem( 72) +  0.8000000000000000D-01 * w(207)
      chem( 73) = chem( 73) +  0.5000000000000000D+00 * w(207)
      chem( 76) = chem( 76) -  0.8800000000000000D+00 * w(207)
      chem( 81) = chem( 81) +  0.3800000000000000D+00 * w(207)
      chem( 57) = chem( 57) - w(208)
      chem( 63) = chem( 63) +  0.5000000000000000D+00 * w(208)
      chem( 73) = chem( 73) +  0.5000000000000000D+00 * w(208)
      chem( 76) = chem( 76) - w(208)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w(208)
      chem( 82) = chem( 82) + w(208)
      chem( 58) = chem( 58) - w(209)
      chem( 63) = chem( 63) +  0.4840000000000000D+00 * w(209)
      chem( 69) = chem( 69) +  0.1670000000000000D+00 * w(209)
      chem( 71) = chem( 71) +  0.6500000000000000D+00 * w(209)
      chem( 73) = chem( 73) +  0.5160000000000000D+00 * w(209)
      chem( 74) = chem( 74) +  0.2070000000000000D+00 * w(209)
      chem( 76) = chem( 76) - w(209)
      chem( 80) = chem( 80) +  0.5160000000000000D+00 * w(209)
      chem( 82) = chem( 82) +  0.4840000000000000D+00 * w(209)
      chem( 57) = chem( 57) -  0.2000000000000000D+01 * w(210)
      chem( 81) = chem( 81) + w(210)
      chem( 82) = chem( 82) +  0.2000000000000000D+01 * w(210)
      chem( 57) = chem( 57) - w(211)
      chem( 58) = chem( 58) - w(211)
      chem( 69) = chem( 69) +  0.1490000000000000D+00 * w(211)
      chem( 71) = chem( 71) +  0.6400000000000000D+00 * w(211)
      chem( 74) = chem( 74) +  0.2020000000000000D+00 * w(211)
      chem( 80) = chem( 80) +  0.5000000000000000D+00 * w(211)
      chem( 81) = chem( 81) +  0.5000000000000000D+00 * w(211)
      chem( 82) = chem( 82) +  0.1500000000000000D+01 * w(211)
      chem( 58) = chem( 58) -  0.2000000000000000D+01 * w(212)
      chem( 69) = chem( 69) +  0.2850000000000000D+00 * w(212)
      chem( 71) = chem( 71) +  0.1210000000000000D+01 * w(212)
      chem( 74) = chem( 74) +  0.5040000000000000D+00 * w(212)
      chem( 80) = chem( 80) + w(212)
      chem( 82) = chem( 82) + w(212)
      chem( 73) = chem( 73) - w(213)
      chem( 74) = chem( 74) + w(213)
      chem( 77) = chem( 77) - w(213)
      chem( 80) = chem( 80) + w(213)
      chem( 81) = chem( 81) + w(213)
      chem( 70) = chem( 70) - w(214)
      chem( 71) = chem( 71) + w(214)
      chem( 77) = chem( 77) - w(214)
      chem( 80) = chem( 80) + w(214)
      chem( 81) = chem( 81) + w(214)
      chem( 61) = chem( 61) +  0.6300000000000000D-01 * w(215)
      chem( 68) = chem( 68) - w(215)
      chem( 69) = chem( 69) +  0.6700000000000000D+00 * w(215)
      chem( 70) = chem( 70) +  0.5300000000000000D-01 * w(215)
      chem( 71) = chem( 71) +  0.2430000000000000D+00 * w(215)
      chem( 72) = chem( 72) +  0.5100000000000000D-01 * w(215)
      chem( 73) = chem( 73) +  0.1550000000000000D+00 * w(215)
      chem( 74) = chem( 74) +  0.4800000000000000D-01 * w(215)
      chem( 77) = chem( 77) - w(215)
      chem( 80) = chem( 80) + w(215)
      chem( 81) = chem( 81) +  0.7920000000000000D+00 * w(215)
      chem( 48) = chem( 48) - w(216)
      chem( 69) = chem( 69) +  0.8280000000000000D+00 * w(216)
      chem( 70) = chem( 70) +  0.2620000000000000D+00 * w(216)
      chem( 71) = chem( 71) +  0.2390000000000000D+00 * w(216)
      chem( 72) = chem( 72) +  0.3910000000000000D+00 * w(216)
      chem( 73) = chem( 73) +  0.4000000000000000D-01 * w(216)
      chem( 74) = chem( 74) +  0.2100000000000000D-01 * w(216)
      chem( 77) = chem( 77) - w(216)
      chem( 80) = chem( 80) + w(216)
      chem( 81) = chem( 81) +  0.6990000000000000D+00 * w(216)
      chem( 49) = chem( 49) - w(217)
      chem( 69) = chem( 69) +  0.8800000000000000D+00 * w(217)
      chem( 70) = chem( 70) +  0.1550000000000000D+00 * w(217)
      chem( 71) = chem( 71) +  0.1870000000000000D+00 * w(217)
      chem( 72) = chem( 72) +  0.5870000000000000D+00 * w(217)
      chem( 77) = chem( 77) - w(217)
      chem( 80) = chem( 80) + w(217)
      chem( 81) = chem( 81) +  0.8450000000000000D+00 * w(217)
      chem( 50) = chem( 50) - w(218)
      chem( 71) = chem( 71) +  0.2000000000000000D+00 * w(218)
      chem( 74) = chem( 74) +  0.1600000000000000D+01 * w(218)
      chem( 77) = chem( 77) - w(218)
      chem( 80) = chem( 80) + w(218)
      chem( 81) = chem( 81) + w(218)
      chem( 54) = chem( 54) - w(219)
      chem( 69) = chem( 69) +  0.6000000000000000D-01 * w(219)
      chem( 71) = chem( 71) +  0.9399999999999999D+00 * w(219)
      chem( 74) = chem( 74) + w(219)
      chem( 77) = chem( 77) - w(219)
      chem( 80) = chem( 80) + w(219)
      chem( 81) = chem( 81) + w(219)
      chem( 62) = chem( 62) - w(220)
      chem( 69) = chem( 69) +  0.2900000000000000D+00 * w(220)
      chem( 71) = chem( 71) +  0.1710000000000000D+01 * w(220)
      chem( 77) = chem( 77) - w(220)
      chem( 80) = chem( 80) + w(220)
      chem( 81) = chem( 81) + w(220)
      chem( 51) = chem( 51) - w(221)
      chem( 52) = chem( 52) +  0.6000000000000000D+00 * w(221)
      chem( 53) = chem( 53) +  0.4000000000000000D+00 * w(221)
      chem( 74) = chem( 74) +  0.6860000000000001D+00 * w(221)
      chem( 77) = chem( 77) - w(221)
      chem( 80) = chem( 80) + w(221)
      chem( 81) = chem( 81) + w(221)
      chem( 55) = chem( 55) - w(222)
      chem( 69) = chem( 69) + w(222)
      chem( 71) = chem( 71) + w(222)
      chem( 77) = chem( 77) - w(222)
      chem( 80) = chem( 80) + w(222)
      chem( 81) = chem( 81) + w(222)
      chem( 47) = chem( 47) - w(223)
      chem( 52) = chem( 52) +  0.6000000000000000D+00 * w(223)
      chem( 56) = chem( 56) +  0.4000000000000000D+00 * w(223)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(223)
      chem( 77) = chem( 77) - w(223)
      chem( 80) = chem( 80) + w(223)
      chem( 81) = chem( 81) + w(223)
      chem( 39) = chem( 39) - w(224)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(224)
      chem( 61) = chem( 61) +  0.1300000000000000D+01 * w(224)
      chem( 66) = chem( 66) +  0.7000000000000000D+00 * w(224)
      chem( 77) = chem( 77) - w(224)
      chem( 80) = chem( 80) + w(224)
      chem( 81) = chem( 81) + w(224)
      chem( 40) = chem( 40) - w(225)
      chem( 46) = chem( 46) + w(225)
      chem( 61) = chem( 61) +  0.7400000000000000D+00 * w(225)
      chem( 66) = chem( 66) +  0.1260000000000000D+01 * w(225)
      chem( 77) = chem( 77) - w(225)
      chem( 80) = chem( 80) + w(225)
      chem( 81) = chem( 81) + w(225)
      chem( 33) = chem( 33) - w(226)
      chem( 61) = chem( 61) + w(226)
      chem( 66) = chem( 66) + w(226)
      chem( 77) = chem( 77) - w(226)
      chem( 80) = chem( 80) + w(226)
      chem( 81) = chem( 81) + w(226)
      chem( 73) = chem( 73) + w(227)
      chem( 76) = chem( 76) - w(227)
      chem( 77) = chem( 77) - w(227)
      chem( 80) = chem( 80) + w(227)
      chem( 74) = chem( 74) + w(228)
      chem( 76) = chem( 76) + w(228)
      chem( 77) = chem( 77) - w(228)
      chem( 79) = chem( 79) - w(228)
      chem( 80) = chem( 80) + w(228)
      chem( 64) = chem( 64) - w(229)
      chem( 66) = chem( 66) +  0.5400000000000000D+00 * w(229)
      chem( 71) = chem( 71) +  0.4600000000000000D+00 * w(229)
      chem( 72) = chem( 72) +  0.1600000000000000D+00 * w(229)
      chem( 76) = chem( 76) +  0.2300000000000000D+00 * w(229)
      chem( 77) = chem( 77) - w(229)
      chem( 80) = chem( 80) + w(229)
      chem( 81) = chem( 81) +  0.7700000000000000D+00 * w(229)
      chem( 57) = chem( 57) - w(230)
      chem( 77) = chem( 77) - w(230)
      chem( 80) = chem( 80) + w(230)
      chem( 81) = chem( 81) + w(230)
      chem( 82) = chem( 82) + w(230)
      chem( 58) = chem( 58) - w(231)
      chem( 69) = chem( 69) +  0.4690000000000000D+00 * w(231)
      chem( 71) = chem( 71) +  0.1240000000000000D+01 * w(231)
      chem( 74) = chem( 74) +  0.2800000000000000D+00 * w(231)
      chem( 77) = chem( 77) - w(231)
      chem( 80) = chem( 80) +  0.2000000000000000D+01 * w(231)
      chem( 65) = chem( 65) + w(232)
      chem( 72) = chem( 72) - w(232)
      chem( 81) = chem( 81) - w(232)
      chem( 72) = chem( 72) - w(233)
      chem( 73) = chem( 73) - w(233)
      chem( 74) = chem( 74) + w(233)
      chem( 81) = chem( 81) + w(233)
      chem( 72) = chem( 72) - w(234)
      chem( 73) = chem( 73) + w(234)
      chem( 76) = chem( 76) - w(234)
      chem( 72) = chem( 72) -  0.2000000000000000D+01 * w(235)
      chem( 72) = chem( 72) - w(236)
      chem( 78) = chem( 78) - w(236)
      chem( 80) = chem( 80) + w(236)
      chem( 72) = chem( 72) - w(237)
      chem( 77) = chem( 77) - w(237)
      chem( 80) = chem( 80) + w(237)
      chem( 45) = chem( 45) +  0.5000000000000000D+00 * w(238)
      chem( 81) = chem( 81) - w(238)
      chem( 32) = chem( 32) +  0.5000000000000000D+00 * w(239)
      chem( 67) = chem( 67) +  0.5000000000000000D+00 * w(239)
      chem( 80) = chem( 80) - w(239)
      chem( 67) = chem( 67) + w(240)
      chem( 77) = chem( 77) - w(240)
      chem( 13) = chem( 13) - w(241)
      chem( 67) = chem( 67) +  0.2000000000000000D+01 * w(241)
C     Volumic source terms.
      
      IF (nemis.gt.0) THEN
         do i=1,NESP
            chem(i)=chem(i)+ZCsourc(i)
         enddo
      ENDIF

      RETURN
      END
      
